<?php

namespace PAR\Controller;

use PAR\Controller\PARCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use PAR\Service\TrocaDeInscricaoParceiroService;
use PAR\Traits\TResponse;

class TrocaDeInscricaoParceiroController extends PARCrud
{
    use TResponse;

    protected $trocaDeInscricaoParceiroService;

    public function __construct($crudService, $environment, TrocaDeInscricaoParceiroService $trocaDeInscricaoParceiroService)
    {
        parent::__construct($crudService, $environment);
        $this->trocaDeInscricaoParceiroService = $trocaDeInscricaoParceiroService;
    }

    public function getInscricaoParceiro(Request $request, Response $response)
    {
        try {
            $data = $this->trocaDeInscricaoParceiroService->getInscricaoParceiro();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function validarInscricaoParceiro(DTO\Request $request, DTO\Response $response)
    {
        try {
            $nrorg = $this->environment->getNrOrg();
            $nrnewinscricao = $request->getParameters()["NRNEWINSCRICAO"];
            $valida = $this->trocaDeInscricaoParceiroService->validarAlteracaoInscricao($nrnewinscricao, $nrorg);
            return $response->addDataSet(new DataSet("alterainscricao", array("VALIDA" => $valida)));
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function alterarInscricaoParceiro(DTO\Request $request, DTO\Response $response)
    {
        try {
            $nrorg    = $this->environment->getNrOrg();
            $operador = $this->environment->getCdOperador();

            $nrparcnegocio    = $request->getParameters()["NRPARCNEGOCIO"];
            $nrnewinscricao   = $request->getParameters()["NRNEWINSCRICAO"];
            $nroldinscricao   = $request->getParameters()["NROLDINSCRICAO"];
            $nmprincipalparc  = $request->getParameters()["NMPRINCIPALPARC"];
            $nmsecundarioparc = $request->getParameters()["NMSECUNDARIPARC"];
            $dsjustificativa  = $request->getParameters()["DSJUSTIFICATIVA"];
            $idinativaparc    = $request->getParameters()["IDINATIVAPARC"];
            $dscaminhoarq     = $request->getParameters()["DSCAMINHOARQ"];
            $this->trocaDeInscricaoParceiroService->alterarInscricaoParceiro($nrparcnegocio, $nrnewinscricao, $nroldinscricao, $nmprincipalparc, $nmsecundarioparc, $dsjustificativa, $idinativaparc, $dscaminhoarq, $nrorg, $operador);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getPermissaoAlteracaoInscParceiro(DTO\Request $request, DTO\Response $response)
    {
        try {
            $nrorg = $this->environment->getNrOrg();
            $nrparcnegocio    = $request->getParameters()["NRPARCNEGOCIO"];
            $permiteAlteracao = $this->trocaDeInscricaoParceiroService->getPermissaoAlteracaoInscParceiro($nrparcnegocio, $nrorg);

            $response->addDataSet(new DataSet("parcnegocio", array("PERMITEALTSM" => $permiteAlteracao)));
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getTermoAnuenciaParceiro(DTO\Request $request, DTO\Response $response)
    {
        try {
            $nrorg = $this->environment->getNrOrg();
            $nrinscricaoparc = $request->getParameters()["NRINSCRICAOPARC"];
            $documentos  = $this->trocaDeInscricaoParceiroService->getTermoAnuenciaParceiro($nrinscricaoparc, $nrorg);
            $response->addDataSet(new DataSet("URLDOCUMENTO", array($documentos)));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}
