<?php

namespace PAR\Factory;

use Doctrine\ORM\EntityManager;
use PAR\Traits\TQuery;

class BusinessPartnerFactory
{

    use TQuery;

    protected $connection;
    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getBusinessPartner()
    {

        $sql = "SELECT TPC.NMCLASSIFICAPARC,
               TPC.NRTPCLASSIFICAPARC,
               PN.NRPARCNEGOCIO,
               PN.CDSEGMER,
               SM.DSSEGMER,
               PN.CDTIPOPARCPRINCIPAL,
               TP.NMTIPOPARCEIRO AS NMTIPOPARCPRINCIPAL,
               PN.CDTIPOINSCRICAO,
               PN.NMPRINCIPALPARC,
               PN.NMSECUNDARIPARC,
               PN.DTNASCIFUNDPARC,
               PN.NRINSCRICAOPARC,
               PN.IDPESSOAFISICA,
               PN.IDINSTITUICAO,
               PN.NRORG,
               PN.IDATIVO,
               PN.DTINCLUSAO,
               PN.DTULTATU,
               PN.CDOPERRESPONSAVEL,
               PN.NRORGINCLUSAO,
               PN.CDOPERINCLUSAO,
               PN.NRORGULTATU,
               PN.CDOPERULTATU,
               PN.DSDEPARTAMENTO,
               PN.CDATIVCLI,
               AC.DSATIVCLI,
               PN.NRSEQTPATIVCLI,
               TC.DSTPATIVCLIENTE,
               PN.IDIDIOMA,
               LISTAGG(PA.CDTIPOPARCEIRO, ', ') WITHIN GROUP(ORDER BY PA.CDTIPOPARCEIRO) TIPODEPARCEIRO,
               INC.NMOPERADOR AS NMOPERINCLUSAO,
               ATU.NMOPERADOR AS NMOPERULTATU,
               OP.NMOPERADOR AS NMOPERRESPONSAVEL,
               DECODE(PN.IDATIVO,'S','Sim','Não') AS NMATIVO,
               PN.CDIDIOM,
                PN.NRMOEDA,
                ID.NMIDIOMA,
                MD.NMMOEDA
          FROM PARCNEGOCIO PN
            LEFT JOIN IDIOMA ID
                ON PN.CDIDIOM = ID.CDIDIOM
            LEFT JOIN FCT_MOEDA MD
                ON PN.NRMOEDA = MD.NRMOEDA
          LEFT JOIN PARCERIA PA
            ON PN.NRPARCNEGOCIO = PA.NRPARCNEGOCIO
           AND PA.IDATIVO       = 'S'
          LEFT JOIN TIPOCLASSIFICAPARC TPC
            ON PN.NRTPCLASSIFICAPARC = TPC.NRTPCLASSIFICAPARC
          LEFT JOIN SEGMERCADO SM
            ON PN.CDSEGMER = SM.CDSEGMER
          LEFT JOIN ATIVCLIENTE AC
            ON PN.CDATIVCLI = AC.CDATIVCLI
          LEFT JOIN TPATIVCLIENTE TC
            ON PN.NRSEQTPATIVCLI = TC.NRSEQTPATIVCLI
          LEFT JOIN TIPOPARCEIRO TP
            ON PN.CDTIPOPARCPRINCIPAL = TP.CDTIPOPARCEIRO
          LEFT JOIN OPERADOR INC
            ON PN.CDOPERINCLUSAO = INC.CDOPERADOR
          LEFT JOIN OPERADOR ATU
            ON PN.CDOPERULTATU = ATU.CDOPERADOR
          LEFT JOIN OPERADOR OP
            ON PN.CDOPERRESPONSAVEL = OP.CDOPERADOR
         WHERE PN.IDPARCFUNDIDO <> 'S'
         GROUP BY TPC.NMCLASSIFICAPARC,
               TPC.NRTPCLASSIFICAPARC,
               PN.NRPARCNEGOCIO,
               PN.CDSEGMER,
               SM.DSSEGMER,
               PN.CDTIPOPARCPRINCIPAL,
               TP.NMTIPOPARCEIRO,
               PN.CDTIPOINSCRICAO,
               PN.NMPRINCIPALPARC,
               PN.NMSECUNDARIPARC,
               PN.DTNASCIFUNDPARC,
               PN.NRINSCRICAOPARC,
               PN.IDPESSOAFISICA,
               PN.IDINSTITUICAO,
               PN.NRORG,
               PN.IDATIVO,
               PN.DTINCLUSAO,
               PN.DTULTATU,
               PN.CDOPERRESPONSAVEL,
               PN.NRORGINCLUSAO,
               PN.CDOPERINCLUSAO,
               PN.NRORGULTATU,
               PN.CDOPERULTATU,
               PN.DSDEPARTAMENTO,
               PN.CDATIVCLI,
               AC.DSATIVCLI,
               PN.NRSEQTPATIVCLI,
               TC.DSTPATIVCLIENTE,
               PN.IDIDIOMA,
               INC.NMOPERADOR,
               ATU.NMOPERADOR,
               OP.NMOPERADOR,
               OP.NRPARCNEGOCIO,
               INC.NMOPERADOR,
               ATU.NMOPERADOR,
               OP.NMOPERADOR,
               ID.NMIDIOMA,
               MD.NMMOEDA,
               PN.CDIDIOM,
               PN.NRMOEDA
         ORDER BY PN.NMPRINCIPALPARC";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getOperator()
    {

        $sql = "SELECT CDOPERADOR, NMOPERADOR || ' (' || DECODE(IDATIVO, 'S', 'Ativo', 'Inativo') || ')' NMOPERADOR
                FROM OPERADOR
                ORDER BY NMOPERADOR";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getPartnerClassification()
    {

        $sql = "SELECT NRTPCLASSIFICAPARC, NMCLASSIFICAPARC
                  FROM TIPOCLASSIFICAPARC
                  ORDER BY NMCLASSIFICAPARC";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getTypeOfPartner()
    {

        $sql = "SELECT CDTIPOPARCEIRO, NMTIPOPARCEIRO
                 FROM TIPOPARCEIRO
                WHERE IDATIVO = 'S'
                AND  CDTIPOPARCEIRO  NOT IN ('ESTRUTURA', 'TRANSPORTADORA')
                ORDER BY NMTIPOPARCEIRO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getMarketSegment()
    {

        $sql = "SELECT CDSEGMER, DSSEGMER
                 FROM SEGMERCADO
                WHERE IDATIVO = 'S'
                ORDER BY DSSEGMER";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getBranchOfActivity()
    {

        $sql = "SELECT CDATIVCLI, DSATIVCLI
                FROM ATIVCLIENTE
                WHERE IDATIVO = 'S'
                ORDER BY DSATIVCLI";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getTypeOfActivity()
    {

        $sql = "SELECT NRSEQTPATIVCLI, DSTPATIVCLIENTE
                FROM TPATIVCLIENTE
                WHERE IDATIVO = 'S'
                ORDER BY DSTPATIVCLIENTE";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getCountry()
    {

        $sql = "SELECT CDPAIS, NMPAIS
                 FROM PAIS
                WHERE IDATIVO = 'S'
                ORDER BY NMPAIS";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getState($parametro)
    {
        $sql = "SELECT SGESTADO, NMESTADO
                 FROM ESTADO
                WHERE IDATIVO = 'S'
                AND CDPAIS = :CDPAIS
                ORDER BY NMESTADO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametro);
    }

    public function getCity($parametro)
    {

        $sql = "SELECT CDMUNICIPIO, NMMUNICIPIO
                 FROM MUNICIPIO
                WHERE IDATIVO = 'S'
                AND CDPAIS = :CDPAIS
                AND SGESTADO = :SGESTADO
                ORDER BY NMMUNICIPIO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametro);
    }

    public function getDistrict($parametro)
    {

        $sql = "SELECT CDBAIRRO, NMBAIRRO
                FROM BAIRRO
                WHERE IDATIVO = 'S'
                AND SGESTADO = :SGESTADO
                AND CDPAIS = :CDPAIS
                AND CDMUNICIPIO = :CDMUNICIPIO
                ORDER BY NMBAIRRO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametro);
    }

    public function findCodeDistrict($parametros)
    {

        $sqlAlter1 = "ALTER SESSION SET NLS_COMP=LINGUISTIC";

        $std = $this->connection->prepare($sqlAlter1);
        $std->execute();

        $sqlAlter2 = "ALTER SESSION SET NLS_SORT=BINARY_AI";

        $std = $this->connection->prepare($sqlAlter2);
        $std->execute();

        $sql = "SELECT CDBAIRRO, NMBAIRRO, SGESTADO
                  FROM BAIRRO
                  WHERE NMBAIRRO LIKE :NMBAIRRO
                  AND IDATIVO = 'S'
                  AND SGESTADO = :SGESTADO
                  AND CDPAIS = :CDPAIS
                  AND CDMUNICIPIO = :CDMUNICIPIO";


        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
        return $std->fetchAll();
    }

    public function getSpecificBusinessPartner($parametro)
    {

        $sql = "SELECT TPC.NMCLASSIFICAPARC,
                 TPC.NRTPCLASSIFICAPARC,
                 PN.NRPARCNEGOCIO,
                 PN.CDSEGMER,
                 SM.DSSEGMER,
                 PN.CDTIPOPARCPRINCIPAL,
                 TP.NMTIPOPARCEIRO AS NMTIPOPARCPRINCIPAL,
                 PN.CDTIPOINSCRICAO,
                 PN.NMPRINCIPALPARC,
                 PN.NMSECUNDARIPARC,
                 TO_CHAR(PN.DTNASCIFUNDPARC, 'DD/MM/YYYY') AS DTNASCIFUNDPARC,
                 PN.NRINSCRICAOPARC,
                 PN.IDPESSOAFISICA,
                 PN.IDINSTITUICAO,
                 PN.NRORG,
                 PN.IDATIVO,
                 TO_CHAR(PN.DTINCLUSAO, 'DD/MM/YYYY HH24:MI') DTINCLUSAO,
                 TO_CHAR(PN.DTULTATU, 'DD/MM/YYYY HH24:MI') DTULTATU,
                 PN.CDOPERRESPONSAVEL,
                 PN.NRORGINCLUSAO,
                 PN.CDOPERINCLUSAO,
                 PN.NRORGULTATU,
                 PN.CDOPERULTATU,
                 PN.DSDEPARTAMENTO,
                 PN.CDATIVCLI,
                 AC.DSATIVCLI,
                 PN.NRSEQTPATIVCLI,
                 TC.DSTPATIVCLIENTE,
                 PN.IDIDIOMA,
                 LISTAGG(PA.CDTIPOPARCEIRO, ', ') WITHIN GROUP(ORDER BY PA.CDTIPOPARCEIRO) TIPODEPARCEIRO,
                 INC.NMOPERADOR AS NMOPERINCLUSAO,
                 ATU.NMOPERADOR AS NMOPERULTATU,
                 OP.NMOPERADOR AS NMOPERRESPONSAVEL,
                 PN.CDINSCMUNI,
                 PN.CDINSCESTA,
                 PN.CDIDIOM,
                 PN.NRMOEDA,
                 ID.NMIDIOMA,
                 MD.NMMOEDA
            FROM PARCNEGOCIO PN
            LEFT JOIN IDIOMA ID
                ON PN.CDIDIOM = ID.CDIDIOM
            LEFT JOIN FCT_MOEDA MD
                ON PN.NRMOEDA = MD.NRMOEDA
            LEFT JOIN PARCERIA PA
              ON PN.NRPARCNEGOCIO = PA.NRPARCNEGOCIO
             AND PA.IDATIVO       = 'S'
            LEFT JOIN TIPOCLASSIFICAPARC TPC
              ON PN.NRTPCLASSIFICAPARC = TPC.NRTPCLASSIFICAPARC
            LEFT JOIN SEGMERCADO SM
              ON PN.CDSEGMER = SM.CDSEGMER
            LEFT JOIN ATIVCLIENTE AC
              ON PN.CDATIVCLI = AC.CDATIVCLI
            LEFT JOIN TPATIVCLIENTE TC
              ON PN.NRSEQTPATIVCLI = TC.NRSEQTPATIVCLI
            LEFT JOIN TIPOPARCEIRO TP
              ON PN.CDTIPOPARCPRINCIPAL = TP.CDTIPOPARCEIRO
            LEFT JOIN OPERADOR INC
              ON PN.CDOPERINCLUSAO = INC.CDOPERADOR
            LEFT JOIN OPERADOR ATU
              ON PN.CDOPERULTATU = ATU.CDOPERADOR
            LEFT JOIN OPERADOR OP
              ON PN.CDOPERRESPONSAVEL = OP.CDOPERADOR
           WHERE PN.IDPARCFUNDIDO <> 'S'
           AND PN.NRPARCNEGOCIO = :NRPARCNEGOCIO
           GROUP BY TPC.NMCLASSIFICAPARC,
                 TPC.NRTPCLASSIFICAPARC,
                 PN.NRPARCNEGOCIO,
                 PN.CDSEGMER,
                 SM.DSSEGMER,
                 PN.CDTIPOPARCPRINCIPAL,
                 TP.NMTIPOPARCEIRO,
                 PN.CDTIPOINSCRICAO,
                 PN.NMPRINCIPALPARC,
                 PN.NMSECUNDARIPARC,
                 PN.DTNASCIFUNDPARC,
                 PN.NRINSCRICAOPARC,
                 PN.IDPESSOAFISICA,
                 PN.IDINSTITUICAO,
                 PN.NRORG,
                 PN.IDATIVO,
                 PN.DTINCLUSAO,
                 PN.DTULTATU,
                 PN.CDOPERRESPONSAVEL,
                 PN.NRORGINCLUSAO,
                 PN.CDOPERINCLUSAO,
                 PN.NRORGULTATU,
                 PN.CDOPERULTATU,
                 PN.DSDEPARTAMENTO,
                 PN.CDATIVCLI,
                 AC.DSATIVCLI,
                 PN.NRSEQTPATIVCLI,
                 TC.DSTPATIVCLIENTE,
                 PN.IDIDIOMA,
                 INC.NMOPERADOR,
                 ATU.NMOPERADOR,
                 OP.NMOPERADOR,
                 OP.NRPARCNEGOCIO,
                 INC.NMOPERADOR,
                 ATU.NMOPERADOR,
                 OP.NMOPERADOR,
                 PN.CDINSCMUNI,
                 PN.CDINSCESTA,
                 ID.NMIDIOMA,
                 MD.NMMOEDA,
                 PN.CDIDIOM,
                 PN.NRMOEDA
           ORDER BY PN.NMSECUNDARIPARC, PN.NMPRINCIPALPARC";

        return $this->connection->executeQuery($sql, $parametro)->fetchAllAssociative();
    }

    public function insertNewBusinessPartner($parametros)
    {
        // debugApi([$parametros]);

        $sql = "INSERT INTO PARCNEGOCIO (NRPARCNEGOCIO, NRORG, CDSEGMER, NMPRINCIPALPARC, NMSECUNDARIPARC,
              DTNASCIFUNDPARC, NRINSCRICAOPARC, IDATIVO, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO,
              NRORGULTATU, CDOPERULTATU, CDTIPOPARCPRINCIPAL, CDTIPOINSCRICAO, IDPESSOAFISICA, IDINSTITUICAO,
              DSDEPARTAMENTO, IDIDIOMA, CDATIVCLI, NRSEQTPATIVCLI, IDPARCFUNDIDO, CDOPERRESPONSAVEL, NRTPCLASSIFICAPARC,
              DSDIRLOGOMARCA, NRINSCESTADUAL, CDINSCESTA, CDINSCMUNI, CDIDIOM, NRMOEDA)
                VALUES (:NRPARCNEGOCIO,
                        :NRORG,
                        :CDSEGMER,
                        :NMPRINCIPALPARC,
                        :NMSECUNDARIPARC,
                        :DTNASCIFUNDPARC,
                        :NRINSCRICAOPARC,
                        'S',
                        SYSDATE,
                        NULL,
                        :NRORGINCLUSAO,
                        :CDOPERINCLUSAO,
                        NULL,
                        NULL,
                        :CDTIPOPARCPRINCIPAL,
                        :CDTIPOINSCRICAO,
                        :IDPESSOAFISICA,
                        :IDINSTITUICAO,
                        NULL,
                        NULL,
                        :CDATIVCLI,
                        :NRSEQTPATIVCLI,
                        'N',
                        :CDOPERRESPONSAVEL,
                        :NRTPCLASSIFICAPARC,
                        NULL,
                        NULL,
                        :CDINSCESTA,
                        :CDINSCMUNI,
                        :CDIDIOM, 
                        :NRMOEDA)";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function insertPartnership($parametros)
    {

        $sql = "INSERT INTO PARCERIA
                VALUES (:NRPARCERIA,
                        :NRPARCNEGOCIO,
                        :CDTIPOPARCEIRO,
                        :NRORG,
                        :IDATIVO,
                        SYSDATE,
                        NULL,
                        :NRORGINCLUSAO,
                        :CDOPERINCLUSAO,
                        NULL,
                        NULL,
                        :NRPARCORIGEM)";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function insertCLIENTE(array $parametros)
    {
        $sql = "INSERT INTO CLIENTE (
                    CDCLIENTE,      IDTPIJURCLIE,   NRINSJURCLIE,
                    NMRAZSOCCLIE,   NMFANTCLIE,     NRORG,
                    DTINCLUSAO,     NRORGINCLUSAO,  CDOPERINCLUSAO,
                    NRPARCNEGOCIO,  CDINSCESTA,     CDINSCMUNI,
                    NRINSESTCLIE,   NRINSMUNICLIE,  IDTPLIMATEFAT,
                    IDATIVO,        IDCLIEATIV,     DTNASCCLIE
                )
                VALUES (
                    :CDCLIENTE,     :IDTPIJURCLIE,  :NRINSJURCLIE,
                    :NMRAZSOCCLIE,  :NMFANTCLIE,    :NRORG,
                    SYSDATE,        :NRORGINCLUSAO, :CDOPERINCLUSAO,
                    :NRPARCNEGOCIO, :CDINSCESTA,    :CDINSCMUNI,
                    :NRINSESTCLIE,  :NRINSMUNICLIE, :IDTPLIMATEFAT,
                    :IDATIVO,       :IDCLIEATIV,    :DTNASCCLIE
                )";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function insertFORNECEDOR($parametros)
    {
        $sql = "INSERT INTO FORNECEDOR (
                    CDFORNECED,     IDTPIJURFORN,   NRINSJURFORN,
                    NMRAZSOCFORN,   NMFANTFORN,     NRORG,
                    DTINCLUSAO,     NRORGINCLUSAO,  CDOPERINCLUSAO,
                    NRPARCNEGOCIO,  IDLIGEXTFORN,   IDBLOQCMPSAFFOR,
                    IDATIVO,        IDSITUCADA
                )
                VALUES (
                    :CDFORNECED,    :IDTPIJURFORN,  :NRINSJURFORN,
                    :NMRAZSOCFORN,  :NMFANTFORN,    :NRORG,
                    SYSDATE,        :NRORGINCLUSAO, :CDOPERINCLUSAO,
                    :NRPARCNEGOCIO, :IDLIGEXTFORN,  :IDBLOQCMPSAFFOR,
                    :IDATIVO,       :IDSITUCADA
                )";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function insertVENDEDOR($parametros)
    {

        $sql = "INSERT INTO VENDEDOR(CDVENDEDOR, IDTPIJURVEN, NRINSJURVEN, NMRAZSOCVEN, NMFANVEN, NRORG, DTINCLUSAO,
                                   NRORGINCLUSAO, CDOPERINCLUSAO, NRPARCNEGOCIO)
                VALUES(:CDVENDEDOR, :IDTPIJURVEN, :NRINSJURVEN, :NMRAZSOCVEN, :NMFANVEN, :NRORG, SYSDATE,
                       :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRPARCNEGOCIO)";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function insertPROSPECT($parametros)
    {

        $sql = "INSERT INTO PROSPECT (CDPROSPECT, IDTPIJURPROS, NRINSJURPROS, NMRAZSOCPROS, NMFANTPROS,
                                    NRORG, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO,NRPARCNEGOCIO, IDATIVO, NRPARCORIGEM)
                VALUES (:CDPROSPECT, :IDTPIJURPROS, :NRINSJURPROS, :NMRAZSOCPROS, :NMFANTPROS,
                        :NRORG, SYSDATE, :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRPARCNEGOCIO, :IDATIVO, :NRPARCORIGEM)";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function updateSpecificBusinessPartner($parametros)
    {
        // debugApi([$parametros]);
        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $std = $this->connection->prepare($sqlAlter);
        $std->execute();

        $sql = "UPDATE PARCNEGOCIO
                SET CDSEGMER = :CDSEGMER,
                    NMPRINCIPALPARC = :NMPRINCIPALPARC,
                    NMSECUNDARIPARC = :NMSECUNDARIPARC,
                    DTNASCIFUNDPARC = :DTNASCIFUNDPARC,
                    NRINSCRICAOPARC = :NRINSCRICAOPARC,
                    IDATIVO = :IDATIVO,
                    DTULTATU = SYSDATE,
                    NRORGULTATU = :NRORGULTATU,
                    CDOPERULTATU = :CDOPERULTATU,
                    CDTIPOPARCPRINCIPAL = :CDTIPOPARCPRINCIPAL,
                    CDTIPOINSCRICAO = :CDTIPOINSCRICAO,
                    IDPESSOAFISICA = :IDPESSOAFISICA,
                    IDINSTITUICAO = :IDINSTITUICAO,
                    CDATIVCLI = :CDATIVCLI,
                    NRSEQTPATIVCLI = :NRSEQTPATIVCLI,
                    CDOPERRESPONSAVEL = :CDOPERRESPONSAVEL,
                    NRTPCLASSIFICAPARC = :NRTPCLASSIFICAPARC,
                    CDINSCESTA = :CDINSCESTA,
                    CDINSCMUNI = :CDINSCMUNI,
                    CDIDIOM = :CDIDIOM,
                    NRMOEDA = :NRMOEDA
                WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function searchForExistingPartnerTypes($parametros)
    {
        $sql = "SELECT CDTIPOPARCEIRO FROM PARCERIA
                WHERE NRPARCNEGOCIO = " . $parametros['NRPARCNEGOCIO'] . "
                AND CDTIPOPARCEIRO NOT IN (" . $parametros['CDTIPOPARCEIRO'] . ")
                AND IDATIVO = 'S'";

        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }

    public function searchForInactivatePartnerTypes($parametros)
    {
        $sql = "SELECT CDTIPOPARCEIRO FROM PARCERIA
                WHERE NRPARCNEGOCIO = " . $parametros . "
                AND IDATIVO = 'N'";

        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }

    public function getQtdParceria($parametros)
    {
        $sql = "SELECT COUNT(*) AS QTD
                  FROM PARCERIA
                 WHERE NRPARCNEGOCIO  = :NRPARCNEGOCIO
                   AND CDTIPOPARCEIRO = :CDTIPOPARCEIRO";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function updateParceria($parametros)
    {
        $sql = "UPDATE PARCERIA
                   SET IDATIVO      = :IDATIVO,
                       DTULTATU     =  SYSDATE,
                       NRORGULTATU  = :NRORGULTATU,
                       CDOPERULTATU = :CDOPERULTATU
                 WHERE NRPARCNEGOCIO  = :NRPARCNEGOCIO
                   AND CDTIPOPARCEIRO = :CDTIPOPARCEIRO";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function updateParceriaNaoSelecionados(array $parametros, $cdtipoparceiro)
    {
        $sql = "UPDATE PARCERIA
                   SET IDATIVO      = :IDATIVO,
                       DTULTATU     =  SYSDATE,
                       NRORGULTATU  = :NRORGULTATU,
                       CDOPERULTATU = :CDOPERULTATU
                 WHERE NRPARCNEGOCIO  = :NRPARCNEGOCIO
                   AND CDTIPOPARCEIRO NOT IN ($cdtipoparceiro)";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function updateCLIENTE(array $parametros)
    {
        $sql = "UPDATE CLIENTE
                   SET NMRAZSOCCLIE  = :NMRAZSOCCLIE,
                       NMFANTCLIE    = :NMFANTCLIE,
                       IDATIVO       = :IDATIVO,
                       IDCLIEATIV    = :IDCLIEATIV,
                       CDINSCESTA    = :CDINSCESTA,
                       CDINSCMUNI    = :CDINSCMUNI,
                       NRINSESTCLIE  = :NRINSESTCLIE,
                       NRINSMUNICLIE = :NRINSMUNICLIE,
                       DTNASCCLIE    = :DTNASCCLIE,
                       IDTPIJURCLIE  = :IDTPIJURCLIE,
                       NRINSJURCLIE  = :NRINSJURCLIE,
                       DTULTATU      = SYSDATE,
                       NRORGULTATU   = :NRORGULTATU,
                       CDOPERULTATU  = :CDOPERULTATU,
                       NRPARCNEGOCIO = :NRPARCNEGOCIO
                 WHERE NRINSJURCLIE  = :NRINSJURCLIE";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function inativarCliente(array $parametros)
    {
        $sql = "UPDATE CLIENTE
                   SET IDATIVO       = :IDATIVO,
                       IDCLIEATIV    = :IDCLIEATIV,
                       DTULTATU      = SYSDATE,
                       NRORGULTATU   = :NRORGULTATU,
                       CDOPERULTATU  = :CDOPERULTATU
                 WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function updateFORNECEDOR($parametros)
    {
        $sql = "UPDATE FORNECEDOR
                   SET NMRAZSOCFORN = :NMRAZSOCFORN,
                       NMFANTFORN   = :NMFANTFORN,
                       IDATIVO      = :IDATIVO,
                       IDSITUCADA   = :IDSITUCADA,
                       IDTPIJURFORN = :IDTPIJURFORN,
                       NRINSJURFORN = :NRINSJURFORN,
                       DTULTATU     = SYSDATE,
                       NRORGULTATU  = :NRORGULTATU,
                       CDOPERULTATU = :CDOPERULTATU,
                       NRPARCNEGOCIO = :NRPARCNEGOCIO
                 WHERE NRINSJURFORN = :NRINSJURFORN";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function inativarFornecedor(array $parametros)
    {
        $sql = "UPDATE FORNECEDOR
                   SET IDATIVO       = :IDATIVO,
                       IDSITUCADA    = :IDSITUCADA,
                       DTULTATU      = SYSDATE,
                       NRORGULTATU   = :NRORGULTATU,
                       CDOPERULTATU  = :CDOPERULTATU
                 WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function updateVENDEDOR($parametros)
    {
        $sql = "UPDATE VENDEDOR
                   SET NMRAZSOCVEN  = :NMRAZSOCVEN,
                       NMFANVEN     = :NMFANVEN,
                       IDATIVO      = :IDATIVO,
                       IDTPIJURVEN  = :IDTPIJURVEN,
                       NRINSJURVEN  = :NRINSJURVEN,
                       DTULTATU     = SYSDATE,
                       NRORGULTATU  = :NRORGULTATU,
                       CDOPERULTATU = :CDOPERULTATU,
                       NRPARCNEGOCIO = :NRPARCNEGOCIO
                 WHERE NRINSJURVEN = :NRINSJURVEN";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function inativarVendedor(array $parametros)
    {
        $sql = "UPDATE VENDEDOR
                   SET IDATIVO       = :IDATIVO,
                       DTULTATU      = SYSDATE,
                       NRORGULTATU   = :NRORGULTATU,
                       CDOPERULTATU  = :CDOPERULTATU
                 WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function updatePROSPECT($parametros)
    {
        $sql = "UPDATE PROSPECT
                   SET NMRAZSOCPROS  = :NMRAZSOCPROS,
                       NMFANTPROS    = :NMFANTPROS,
                       IDATIVO       = :IDATIVO,
                       IDTPIJURPROS  = :IDTPIJURPROS,
                       NRINSJURPROS  = :NRINSJURPROS,
                       DTULTATU      = SYSDATE,
                       NRORGULTATU   = :NRORGULTATU,
                       CDOPERULTATU  = :CDOPERULTATU,
                       NRPARCNEGOCIO = :NRPARCNEGOCIO
                 WHERE NRINSJURPROS  = :NRINSJURPROS";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function inativarProspect(array $parametros)
    {
        $sql = "UPDATE PROSPECT
                   SET IDATIVO       = :IDATIVO,
                       DTULTATU      = SYSDATE,
                       NRORGULTATU   = :NRORGULTATU,
                       CDOPERULTATU  = :CDOPERULTATU
                 WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

        $this->connection->executeStatement($sql, $parametros);
    }

    // ------------------------- ENDEREÇO --------------------------------------------------------------------------

    public function getBusinessPartnerAddress($parametro)
    {

        $sql = "SELECT EP.*, P.NMPAIS, E.NMESTADO, M.NMMUNICIPIO, B.NMBAIRRO, L.DSLOGRADOURO, TE.NMTIPOENDERECO
                  FROM ENDERECOPARC EP
                  LEFT JOIN PAIS P
                       ON P.CDPAIS = EP.CDPAIS
                      AND P.NRORG = EP.NRORG
                  LEFT JOIN ESTADO E
                       ON E.SGESTADO = EP.SGESTADO
                      AND E.CDPAIS = P.CDPAIS AND E.NRORG = EP.NRORG
                  LEFT JOIN MUNICIPIO M
                       ON M.CDMUNICIPIO = EP.CDMUNICIPIO
                      AND M.SGESTADO = E.SGESTADO
                      AND M.NRORG = EP.NRORG
                  LEFT JOIN BAIRRO B
                       ON B.CDBAIRRO = EP.CDBAIRRO
                      AND B.CDMUNICIPIO = M.CDMUNICIPIO
                      AND(B.NRORG = EP.NRORG OR B.NRORG = 0)
                  LEFT JOIN LOGRADOURO L
                       ON L.CDLOGRADOURO = EP.CDLOGRADOURO
                      AND L.NRORG = EP.NRORG
                  LEFT JOIN TIPOENDERECO TE
                       ON TE.CDTIPOENDERECO = EP.CDTIPOENDERECO
                      AND TE.NRORG = EP.NRORG
                  WHERE EP.IDATIVO = 'S'
                  AND EP.NRPARCNEGOCIO = :NRPARCNEGOCIO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametro);
    }

    public function getSpecificAddress($parametro)
    {

        $sql = "SELECT EP.*, P.NMPAIS, E.NMESTADO, M.NMMUNICIPIO, B.NMBAIRRO, L.DSLOGRADOURO, TE.NMTIPOENDERECO
                  FROM ENDERECOPARC EP
                  LEFT JOIN PAIS P
                       ON P.CDPAIS = EP.CDPAIS
                      AND P.NRORG = EP.NRORG
                  LEFT JOIN ESTADO E
                       ON E.SGESTADO = EP.SGESTADO
                      AND E.CDPAIS = P.CDPAIS AND E.NRORG = EP.NRORG
                  LEFT JOIN MUNICIPIO M
                       ON M.CDMUNICIPIO = EP.CDMUNICIPIO
                      AND M.SGESTADO = E.SGESTADO
                      AND M.NRORG = EP.NRORG
                  LEFT JOIN BAIRRO B
                       ON B.CDBAIRRO = EP.CDBAIRRO
                      AND B.CDMUNICIPIO = M.CDMUNICIPIO
                      AND(B.NRORG = EP.NRORG OR B.NRORG = 0)
                  LEFT JOIN LOGRADOURO L
                       ON L.CDLOGRADOURO = EP.CDLOGRADOURO
                      AND L.NRORG = EP.NRORG
                  LEFT JOIN TIPOENDERECO TE
                       ON TE.CDTIPOENDERECO = EP.CDTIPOENDERECO
                      AND TE.NRORG = EP.NRORG
                  WHERE EP.IDATIVO = 'S'
                  AND EP.NRENDERECOPARC = :NRENDERECOPARC";

        $std = $this->connection->prepare($sql);
        $std->execute($parametro);
        return $std->fetchAll();
    }

    public function insertNewAddress($parametros)
    {

        $sql = "INSERT INTO ENDERECOPARC (NRENDERECOPARC, NRPARCNEGOCIO, CDTIPOENDERECO, NRORG, IDATIVO, DTINCLUSAO,
              NRORGINCLUSAO, CDOPERINCLUSAO, CDPAIS, SGESTADO, CDMUNICIPIO, CDBAIRRO, NMBAIRROENDERECO, DSCOMPLEENDERECO, NRCEPENDERECO, DSENDERECO, NRIMOVELENDERECO, DSREFERENCIAENDE)
                VALUES (:NRENDERECOPARC,
                        :NRPARCNEGOCIO,
                        :CDTIPOENDERECO,
                        :NRORG,
                        'S',
                        SYSDATE,
                        :NRORGINCLUSAO,
                        :CDOPERINCLUSAO,
                        :CDPAIS,
                        :SGESTADO,
                        :CDMUNICIPIO,
                        :CDBAIRRO,
                        :NMBAIRROENDERECO,
                        :DSCOMPLEENDERECO,
                        :NRCEPENDERECO,
                        :DSENDERECO,
                        :NRIMOVELENDERECO,
                        :DSREFERENCIAENDE)";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function deleteAddress(array $params)
    {
        $sql = "DELETE FROM ENDERECOPARC
                WHERE NRENDERECOPARC = :NRENDERECOPARC";

        $this->connection->executeStatement($sql, $params);
    }

    public function updateAddress($parametros)
    {
        // debugApi([$parametros]);

        $sql = "UPDATE ENDERECOPARC
                  SET CDTIPOENDERECO = :CDTIPOENDERECO,
                      IDATIVO = 'S',
                      DTULTATU = SYSDATE,
                      NRORGULTATU = :NRORGULTATU,
                      CDOPERULTATU = :CDOPERULTATU,
                      CDPAIS = :CDPAIS,
                      SGESTADO = :SGESTADO,
                      CDMUNICIPIO = :CDMUNICIPIO,
                      CDBAIRRO = :CDBAIRRO,
                      NMBAIRROENDERECO = :NMBAIRROENDERECO,
                      DSCOMPLEENDERECO = :DSCOMPLEENDERECO,
                      NRCEPENDERECO = :NRCEPENDERECO,
                      DSENDERECO = :DSENDERECO,
                      NRIMOVELENDERECO = :NRIMOVELENDERECO,
                      DSREFERENCIAENDE = :DSREFERENCIAENDE
                WHERE NRENDERECOPARC = :NRENDERECOPARC
                  AND NRPARCNEGOCIO = :NRPARCNEGOCIO";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    //  ---------------------------------- FUNÇÕES DA TAB DE FORMAS DE COMUNICAÇÃO ----------------------------------

    public function getListWaysOfCommunication()
    {
        $sql = "SELECT CDFORMACOMU, NMFORMACOMU, DTULTATUFORC, NRORG, DTINCLUSAO, DTULTATU, NRORGINCLUSAO,
                  CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU, IDATIVO
                    FROM FORMACOMU
                    WHERE IDATIVO = 'S'
                    ORDER BY NMFORMACOMU";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getWayOfCommunication($parametro)
    {
        $sql = "SELECT CP.NRCOMUNICAPARC,
                  CP.NRPARCNEGOCIO,
                  CP.CDFORMACOMU,
                  CP.NRENDERECOPARC,
                  CP.CDPREFIXCOMUPARC,
                  CP.CDCOMUNICAPARC,
                  CP.NRORG, CP.NRORGINCLUSAO, CP.NRORGULTATU,
                  CP.IDATIVO,
                  CP.DTINCLUSAO, CP.DTULTATU,
                  CP.CDOPERINCLUSAO, CP.CDOPERULTATU,
                  CP.CDCOMPLECOMUPARC,
                  CP.DSCONTATO,
                  FC.NMFORMACOMU
              FROM COMUNICAPARC CP
              JOIN FORMACOMU FC
                  ON FC.CDFORMACOMU = CP.CDFORMACOMU
              WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO
              ORDER BY FC.NMFORMACOMU, CP.CDCOMUNICAPARC";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametro);
    }

    public function getSpecificWayOfCommunication($parametro)
    {
        $sql = "SELECT CP.NRCOMUNICAPARC,
                  CP.NRPARCNEGOCIO,
                  CP.CDFORMACOMU,
                  CP.NRENDERECOPARC,
                  CP.CDPREFIXCOMUPARC,
                  CP.CDCOMUNICAPARC,
                  CP.NRORG, CP.NRORGINCLUSAO, CP.NRORGULTATU,
                  CP.IDATIVO,
                  CP.DTINCLUSAO, CP.DTULTATU,
                  CP.CDOPERINCLUSAO, CP.CDOPERULTATU,
                  CP.CDCOMPLECOMUPARC,
                  CP.DSCONTATO,
                  FC.NMFORMACOMU
              FROM COMUNICAPARC CP
              JOIN FORMACOMU FC
                  ON FC.CDFORMACOMU = CP.CDFORMACOMU
              WHERE NRCOMUNICAPARC = :NRCOMUNICAPARC
              ORDER BY FC.NMFORMACOMU";

        $std = $this->connection->prepare($sql);
        $std->execute($parametro);
        return $std->fetchAll();
    }

    public function insertNewCommunicationData($parametros)
    {
        $sql = "INSERT INTO COMUNICAPARC
              VALUES (:NRCOMUNICAPARC,
                      :NRPARCNEGOCIO,
                      LPAD(:CDFORMACOMU, 2, '0'),
                      :NRENDERECOPARC,
                      :CDPREFIXCOMUPARC,
                      :CDCOMUNICAPARC,
                      :NRORG,
                      'S',
                      SYSDATE,
                      :DTULTATU,
                      :NRORGINCLUSAO,
                      :CDOPERINCLUSAO,
                      :NRORGULTATU,
                      :CDOPERULTATU,
                      :CDCOMPLECOMUPARC,
                      :DSCONTATO)";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function deleteWayOfCommunication($parametro)
    {
        $sql = "DELETE FROM COMUNICAPARC
                WHERE NRCOMUNICAPARC IN (" . $parametro['NRCOMUNICAPARC'] . ")";

        $std = $this->connection->prepare($sql);
        $std->execute();
    }

    public function updateWayOfCommunication($parametros)
    {
        $sql = "UPDATE COMUNICAPARC
                  SET CDFORMACOMU = LPAD(:CDFORMACOMU, 2, '0'),
                      NRENDERECOPARC = :NRENDERECOPARC,
                      CDPREFIXCOMUPARC = :CDPREFIXCOMUPARC,
                      CDCOMUNICAPARC = :CDCOMUNICAPARC,
                      IDATIVO = 'S',
                      DTULTATU = SYSDATE,
                      NRORGULTATU = :NRORGULTATU,
                      CDOPERULTATU = :CDOPERULTATU,
                      CDCOMPLECOMUPARC = :CDCOMPLECOMUPARC,
                      DSCONTATO = :DSCONTATO
                WHERE NRCOMUNICAPARC = :NRCOMUNICAPARC
                  AND NRPARCNEGOCIO = :NRPARCNEGOCIO";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    //  ---------------------------------- FUNÇÕES DA TAB DE INTERLOCUTOR ----------------------------------
    public function getSectors()
    {
        $sql = "SELECT *
                FROM SETOR
                WHERE IDATIVO = 'S'
                ORDER BY NMSETOR";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getPositionsOfInterlocutors()
    {
        $sql = "SELECT CDCARGOINTERLOC, NMCARGOINTERLOC, DTULTATU, NRORG, DTINCLUSAO, NRORGINCLUSAO,
              CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU, IDATIVO
                 FROM CARGOINTERLOC
                WHERE IDATIVO = 'S'
                ORDER BY NMCARGOINTERLOC";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getInterlocutors($parametro)
    {
        $sql = "SELECT INTER.*,
                SETOR.NMSETOR,
                CARGO.NMCARGOINTERLOC,
                PAIS.NMPAIS,
                ESTADO.NMESTADO,
                MUNICIPIO.NMMUNICIPIO,
                BAIRRO.NMBAIRRO
            FROM CRM_INTERLOCUTOR INTER
            LEFT JOIN CARGOINTERLOC CARGO
                 ON INTER.CDCARGOINTERLOC = CARGO.CDCARGOINTERLOC
                AND INTER.NRORG = CARGO.NRORG
            LEFT JOIN SETOR SETOR
                 ON INTER.CDSETOR = SETOR.CDSETOR
                AND INTER.NRORG = SETOR.NRORG
            LEFT JOIN PAIS
                 ON PAIS.CDPAIS = INTER.CDPAIS
                AND PAIS.NRORG = INTER.NRORG
            LEFT JOIN ESTADO
                 ON ESTADO.SGESTADO = INTER.SGESTADO
                AND ESTADO.CDPAIS = INTER.CDPAIS
                AND ESTADO.NRORG = INTER.NRORG
            LEFT JOIN MUNICIPIO
                 ON MUNICIPIO.CDPAIS = INTER.CDPAIS
                AND MUNICIPIO.SGESTADO = INTER.SGESTADO
                AND MUNICIPIO.CDMUNICIPIO = INTER.CDMUNICIPIO
                AND MUNICIPIO.NRORG = INTER.NRORG
            LEFT JOIN BAIRRO
                 ON BAIRRO.CDPAIS = INTER.CDPAIS
                AND BAIRRO.SGESTADO = INTER.SGESTADO
                AND BAIRRO.CDMUNICIPIO = INTER.CDMUNICIPIO
                AND BAIRRO.CDBAIRRO = INTER.CDBAIRRO
                AND BAIRRO.NRORG = INTER.NRORG
            WHERE INTER.NRPARCNEGOCIO = :NRPARCNEGOCIO
            ORDER BY INTER.NMINTERLOCUTOR";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametro);
    }

    public function getSpecificInterlocutor($parametro)
    {
        $sql = "SELECT INTER.NRSEQINTERLOCUTOR,
                       INTER.NMINTERLOCUTOR,
                       INTER.NRPARCNEGOCIO,
                       INTER.EMAILINTERLOC,
                       INTER.NRTELEFONE1,
                       INTER.NRTELEFONE2,
                       INTER.NRTELEFONE3,
                       INTER.NRTELEFONE4,
                       INTER.CDCARGOINTERLOC,
                       TO_CHAR(INTER.DTNASCIMENTO, 'DD/MM/YYYY') AS DTNASCIMENTO,
                       INTER.IDRECEBEPRESENTE,
                       INTER.CDPAIS,
                       INTER.SGESTADO,
                       INTER.CDMUNICIPIO,
                       INTER.CDBAIRRO,
                       INTER.NRCEPINTERLOCUTOR,
                       INTER.DSENDEINTERLOCUTOR,
                       INTER.DSCOMPINTERLOCUTOR,
                       INTER.NRENDEINTERLOCUTOR,
                       INTER.NRORG,
                       INTER.IDATIVO,
                       INTER.DTINCLUSAO,
                       INTER.DTULTATU,
                       INTER.NRORGINCLUSAO,
                       INTER.NRORGULTATU,
                       INTER.CDOPERINCLUSAO,
                       INTER.CDOPERULTATU,
                       INTER.IDORIGEM,
                       INTER.CDSETOR,
                       INTER.NRCPFINTERLOC,
                       INTER.NRRAMALTEL1,
                       INTER.NRRAMALTEL2,
                       INTER.NRRAMALTEL3,
                       INTER.NRRAMALTEL4,
                       INTER.IDTPSIGNATARIO,
                       INTER.IDNOMEVINDODAAPI,
                       SETOR.NMSETOR,
                       CARGO.NMCARGOINTERLOC,
                       PAIS.NMPAIS,
                       ESTADO.NMESTADO,
                       MUNICIPIO.NMMUNICIPIO,
                       BAIRRO.NMBAIRRO
                  FROM CRM_INTERLOCUTOR INTER
             LEFT JOIN CARGOINTERLOC CARGO
                    ON INTER.CDCARGOINTERLOC = CARGO.CDCARGOINTERLOC
                   AND INTER.NRORG = CARGO.NRORG
             LEFT JOIN SETOR SETOR
                    ON INTER.CDSETOR = SETOR.CDSETOR
                   AND INTER.NRORG = SETOR.NRORG
             LEFT JOIN PAIS
                    ON PAIS.CDPAIS = INTER.CDPAIS
                   AND PAIS.NRORG = INTER.NRORG
             LEFT JOIN ESTADO
                    ON ESTADO.SGESTADO = INTER.SGESTADO
                   AND ESTADO.CDPAIS = INTER.CDPAIS
                   AND ESTADO.NRORG = INTER.NRORG
             LEFT JOIN MUNICIPIO
                    ON MUNICIPIO.CDPAIS = INTER.CDPAIS
                   AND MUNICIPIO.SGESTADO = INTER.SGESTADO
                   AND MUNICIPIO.CDMUNICIPIO = INTER.CDMUNICIPIO
                   AND MUNICIPIO.NRORG = INTER.NRORG
             LEFT JOIN BAIRRO
                    ON BAIRRO.CDPAIS = INTER.CDPAIS
                   AND BAIRRO.SGESTADO = INTER.SGESTADO
                   AND BAIRRO.CDMUNICIPIO = INTER.CDMUNICIPIO
                   AND BAIRRO.CDBAIRRO = INTER.CDBAIRRO
                   AND BAIRRO.NRORG = INTER.NRORG
                 WHERE INTER.NRSEQINTERLOCUTOR = :NRSEQINTERLOCUTOR
                 ORDER BY INTER.NMINTERLOCUTOR";

        return $this->connection->executeQuery($sql, $parametro)->fetchAllAssociative();
    }

    public function insertNewInterlocutor($parametros)
    {
        $sql = "INSERT INTO CRM_INTERLOCUTOR (NRSEQINTERLOCUTOR, NMINTERLOCUTOR, NRPARCNEGOCIO, EMAILINTERLOC, NRTELEFONE1,
                NRTELEFONE2, NRTELEFONE3, NRTELEFONE4, CDCARGOINTERLOC, DTNASCIMENTO, IDRECEBEPRESENTE, CDPAIS, SGESTADO,
                CDMUNICIPIO, CDBAIRRO, NRCEPINTERLOCUTOR, DSENDEINTERLOCUTOR, DSCOMPINTERLOCUTOR, NRENDEINTERLOCUTOR,
                NRORG, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, CDSETOR, NRCPFINTERLOC, IDTPSIGNATARIO,
                IDNOMEVINDODAAPI)
              VALUES (" . $parametros['NRSEQINTERLOCUTOR'] . ",
                      '" . $parametros['NMINTERLOCUTOR'] . "',
                      " . $parametros['NRPARCNEGOCIO'] . ",
                      '" . $parametros['EMAILINTERLOC'] . "',
                      '" . $parametros['NRTELEFONE1'] . "',
                      '" . $parametros['NRTELEFONE2'] . "',
                      '" . $parametros['NRTELEFONE3'] . "',
                      '" . $parametros['NRTELEFONE4'] . "',
                      '" . $parametros['CDCARGOINTERLOC'] . "',
                      '" . $parametros['DTNASCIMENTO'] . "',
                      '" . $parametros['IDRECEBEPRESENTE'] . "',
                      '" . $parametros['CDPAIS'] . "',
                      '" . $parametros['SGESTADO'] . "',
                      '" . $parametros['CDMUNICIPIO'] . "',
                      '" . $parametros['CDBAIRRO'] . "',
                      '" . $parametros['NRCEPINTERLOCUTOR'] . "',
                      '" . $parametros['DSENDEINTERLOCUTOR'] . "',
                      '" . $parametros['DSCOMPINTERLOCUTOR'] . "',
                      '" . $parametros['NRENDEINTERLOCUTOR'] . "',
                      " . $parametros['NRORG'] . ",
                      'S',
                       SYSDATE,
                      " . $parametros['NRORGINCLUSAO'] . ",
                      '" . $parametros['CDOPERINCLUSAO'] . "',
                      '" . $parametros['CDSETOR'] . "',
                      '" . $parametros['NRCPFINTERLOC'] . "',
                      '" . $parametros['IDTPSIGNATARIO'] . "',
                      '" . $parametros['IDNOMEVINDODAAPI'] . "')";

        // debugApi([$sql]);
        $std = $this->connection->prepare($sql);
        $std->execute();
    }

    public function deleteInterlocutor($parametros)
    {
        // debugApi([$parametros]);

        $sql = "DELETE FROM CRM_INTERLOCUTOR
                WHERE NRSEQINTERLOCUTOR IN (" . $parametros['NRSEQINTERLOCUTOR'] . ")
                AND NRPARCNEGOCIO = " . $parametros['NRPARCNEGOCIO'];

        $std = $this->connection->prepare($sql);
        $std->execute();
    }

    public function updateInterlocutor($parametros)
    {
        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $std = $this->connection->prepare($sqlAlter);
        $std->execute();

        $sql = "UPDATE CRM_INTERLOCUTOR
                  SET NMINTERLOCUTOR = :NMINTERLOCUTOR,
                      EMAILINTERLOC = :EMAILINTERLOC,
                      NRTELEFONE1 = :NRTELEFONE1,
                      NRTELEFONE2 = :NRTELEFONE2,
                      NRTELEFONE3 = :NRTELEFONE3,
                      NRTELEFONE4 = :NRTELEFONE4,
                      CDCARGOINTERLOC = :CDCARGOINTERLOC,
                      DTNASCIMENTO = :DTNASCIMENTO,
                      IDRECEBEPRESENTE = :IDRECEBEPRESENTE,
                      CDPAIS = :CDPAIS,
                      SGESTADO = :SGESTADO,
                      CDMUNICIPIO = :CDMUNICIPIO,
                      CDBAIRRO = :CDBAIRRO,
                      NRCEPINTERLOCUTOR = :NRCEPINTERLOCUTOR,
                      DSENDEINTERLOCUTOR = :DSENDEINTERLOCUTOR,
                      DSCOMPINTERLOCUTOR = :DSCOMPINTERLOCUTOR,
                      NRENDEINTERLOCUTOR = :NRENDEINTERLOCUTOR,
                      NRORGULTATU = :NRORGULTATU,
                      CDOPERULTATU = :CDOPERULTATU,
                      IDATIVO = 'S',
                      DTULTATU = SYSDATE,
                      CDSETOR = :CDSETOR,
                      NRCPFINTERLOC = :NRCPFINTERLOC,
                      IDTPSIGNATARIO = :IDTPSIGNATARIO,
                      IDNOMEVINDODAAPI = :IDNOMEVINDODAAPI
            WHERE NRSEQINTERLOCUTOR = :NRSEQINTERLOCUTOR
            AND NRPARCNEGOCIO = :NRPARCNEGOCIO";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    //  ---------------------------------- FUNÇÕES DA TAB DE DADOS BANCARIOS  ----------------------------------
    public function getBankDetails($parametro)
    {
        $sql = "SELECT BANCO.NMBANCO,
                  AGENCIA.NMAGENCIA,
                  CONTCORR.DSCONTCORR,
                  TPCONTCORR.DSTPCONTCORR,
                  CONTPARC.*
              FROM CONTCORRPARC CONTPARC
              LEFT JOIN BANCO
                  ON BANCO.CDBANCO = CONTPARC.CDBANCO
                  AND BANCO.NRORG = CONTPARC.NRORG
              LEFT JOIN AGENCIA
                  ON AGENCIA.CDAGENCIA = CONTPARC.CDAGENCIA
                  AND AGENCIA.NRORG = CONTPARC.NRORG
              LEFT JOIN CONTCORR
                  ON CONTCORR.CDCONTCORR = CONTPARC.CDCONTCORR
                  AND CONTCORR.NRORG = CONTPARC.NRORG
              LEFT JOIN TPCONTCORR
                  ON TPCONTCORR.NRTPCONTCORR = CONTPARC.NRTPCONTCORR
                  AND TPCONTCORR.NRORG = CONTPARC.NRORG
              WHERE CONTPARC.NRPARCNEGOCIO = :NRPARCNEGOCIO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametro);
    }

    public function getSpecificBankDetails($parametro)
    {
        $sql = "SELECT BANCO.NMBANCO,
                  AGENCIA.NMAGENCIA,
                  CONTCORR.DSCONTCORR,
                  TPCONTCORR.DSTPCONTCORR,
                  CONTPARC.*
              FROM CONTCORRPARC CONTPARC
              LEFT JOIN BANCO
                  ON BANCO.CDBANCO = CONTPARC.CDBANCO
                  AND BANCO.NRORG = CONTPARC.NRORG
              LEFT JOIN AGENCIA
                  ON AGENCIA.CDAGENCIA = CONTPARC.CDAGENCIA
                  AND AGENCIA.NRORG = CONTPARC.NRORG
              LEFT JOIN CONTCORR
                  ON CONTCORR.CDCONTCORR = CONTPARC.CDCONTCORR
                  AND CONTCORR.NRORG = CONTPARC.NRORG
              LEFT JOIN TPCONTCORR
                  ON TPCONTCORR.NRTPCONTCORR = CONTPARC.NRTPCONTCORR
                  AND TPCONTCORR.NRORG = CONTPARC.NRORG
              WHERE CONTPARC.NRCONTCORRPARC = :NRCONTCORRPARC";

        $std = $this->connection->prepare($sql);
        $std->execute($parametro);
        return $std->fetchAll();
    }

    public function insertNewBankDetails($parametros)
    {
        $sql = "INSERT INTO CONTCORRPARC
                  VALUES (:NRCONTCORRPARC,
                          :NRORG,
                          :NRPARCNEGOCIO,
                          NULL,
                          :CDBANCO,
                          :CDAGENCIA,
                          :CDCONTCORR,
                          :NRTPCONTCORR,
                          SYSDATE,
                          NULL,
                          :NRORGINCLUSAO,
                          :CDOPERINCLUSAO,
                          NULL,
                          NULL)";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function deleteBankDetails($parametros)
    {
        // debugApi([$parametros]);
        $sql = "DELETE FROM CONTCORRPARC
                WHERE NRCONTCORRPARC IN (" . $parametros['NRCONTCORRPARC'] . ")
                  AND NRPARCNEGOCIO = " . $parametros['NRPARCNEGOCIO'];

        $std = $this->connection->prepare($sql);
        $std->execute();
    }

    public function updateBankDetails($parametros)
    {
        $sql = "UPDATE CONTCORRPARC
                SET CDREDUCONT = NULL,
                    CDBANCO = :CDBANCO,
                    CDAGENCIA = :CDAGENCIA,
                    CDCONTCORR = :CDCONTCORR,
                    NRTPCONTCORR = :NRTPCONTCORR,
                    DTULTATU = SYSDATE,
                    NRORGULTATU = :NRORGULTATU,
                    CDOPERULTATU = :CDOPERULTATU
                WHERE NRCONTCORRPARC = :NRCONTCORRPARC
                AND NRPARCNEGOCIO = :NRPARCNEGOCIO";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function getBanks()
    {
        $sql = "SELECT *
                FROM BANCO
                WHERE IDATIVO = 'S'
                ORDER BY NMBANCO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getAgencies($parametro)
    {
        $sql = "SELECT *
                FROM AGENCIA
                WHERE IDATIVO = 'S'
                AND CDBANCO = :CDBANCO
                ORDER BY NMAGENCIA";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametro);
    }

    public function getCheckingAccount($parametro)
    {
        $sql = "SELECT *
                FROM CONTCORR
                WHERE CDBANCO = :CDBANCO
                AND CDAGENCIA = :CDAGENCIA
                ORDER BY DSCONTCORR";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametro);
    }

    public function getTypeOfCheckingAccount()
    {
        $sql = "SELECT NRTPCONTCORR, DSTPCONTCORR, NRORG, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU,
              CDOPERULTATU
                FROM TPCONTCORR";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    //  ---------------------------------- FUNÇÕES DA TAB DE PARAMETROS DE FATURAMENTO  ----------------------
    public function getBranches()
    {
        $sql = "SELECT CDFILIAL, CDFILIAL || ' | ' || NMFILIAL AS NMFILIAL
                FROM FILIAL
                ORDER BY CDFILIAL";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getInvoiceSeries()
    {
        $sql = "SELECT CDEMPRESA, CDINSCESTA, CDINSCMUNI, CDSERIE,
              DSSERIE || ' | ' || CDINSCESTA  || ' | ' || CDINSCMUNI AS DSSERIE
                FROM SERIENF
                WHERE IDATIVO = 'S'
                ORDER BY DSSERIE";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getBillingParameter($parametro)
    {
        $sql = "SELECT PAR_PARAMFATURA.NRPARAMFATURA,
                PAR_PARAMFATURA.NRPARCNEGOCIO,
                PAR_PARAMFATURA.CDFILIALFATURA,
                FILIAL.NMFILIAL AS NMFILIALFATURA,
                PAR_PARAMFATURA.CDSERIENF,
                SERIENF.DSSERIE,
                PAR_PARAMFATURA.CDEMPRESA,
                PAR_PARAMFATURA.CDINSCESTA,
                PAR_PARAMFATURA.CDINSCMUNI,
                PAR_PARAMFATURA.IDATIVO,
                PAR_PARAMFATURA.NRORG,
                PAR_PARAMFATURA.DTINCLUSAO,
                PAR_PARAMFATURA.CDOPERINCLUSAO,
                PAR_PARAMFATURA.NRORGINCLUSAO,
                PAR_PARAMFATURA.DTULTATU,
                PAR_PARAMFATURA.CDOPERULTATU,
                PAR_PARAMFATURA.NRORGULTATU
            FROM PAR_PARAMFATURA
            LEFT JOIN FILIAL
                ON FILIAL.CDFILIAL = PAR_PARAMFATURA.CDFILIALFATURA
                AND FILIAL.NRORG = PAR_PARAMFATURA.NRORG
            LEFT JOIN SERIENF
                ON SERIENF.CDSERIE = PAR_PARAMFATURA.CDSERIENF
                AND SERIENF.CDEMPRESA = PAR_PARAMFATURA.CDEMPRESA
                AND SERIENF.CDINSCESTA = PAR_PARAMFATURA.CDINSCESTA
                AND SERIENF.CDINSCMUNI = PAR_PARAMFATURA.CDINSCMUNI
                AND SERIENF.NRORG = PAR_PARAMFATURA.NRORG
            WHERE PAR_PARAMFATURA.NRPARCNEGOCIO = :NRPARCNEGOCIO";

        $std = $this->connection->prepare($sql);
        $std->execute($parametro);
        return $std->fetchAll();
    }

    public function insertBillingParameter($parametros)
    {
        $sql = "INSERT INTO PAR_PARAMFATURA
                VALUES (:NRPARAMFATURA,
                        :NRPARCNEGOCIO,
                        :CDFILIALFATURA,
                        :CDSERIENF,
                        :CDEMPRESA,
                        :CDINSCESTA,
                        :CDINSCMUNI,
                        :NRORG,
                        'S',
                        SYSDATE,
                        NULL,
                        :NRORGINCLUSAO,
                        :CDOPERINCLUSAO,
                        NULL,
                        NULL)";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function updateBillingParameter($parametros)
    {
        $sql  = "UPDATE PAR_PARAMFATURA
                    SET CDFILIALFATURA =:CDFILIALFATURA,
                        CDSERIENF = :CDSERIENF,
                        CDEMPRESA = :CDEMPRESA,
                        CDINSCESTA = :CDINSCESTA,
                        CDINSCMUNI = :CDINSCMUNI,
                        DTULTATU = SYSDATE,
                        NRORGULTATU = :NRORGULTATU,
                        CDOPERULTATU = :CDOPERULTATU
                WHERE NRPARAMFATURA = :NRPARAMFATURA
                AND NRPARCNEGOCIO = :NRPARCNEGOCIO";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function sendImage($parametros)
    {
        $sql = "UPDATE PARCNEGOCIO
                SET DSDIRLOGOMARCA = :DSDIRLOGOMARCA,
                    DSTYPELOGOTIPO = :DSTYPELOGOTIPO,
                    QTSIZELOGOTIPO = :QTSIZELOGOTIPO,
                    DTULTATU = SYSDATE
              WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function deleteImage($parametros)
    {
        $sql = "UPDATE PARCNEGOCIO
                SET DSDIRLOGOMARCA = NULL,
                    DSTYPELOGOTIPO = NULL,
                    QTSIZELOGOTIPO = NULL
                WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function getImagesLogotype($parametro)
    {
        $sql = "SELECT DSDIRLOGOMARCA
               FROM PARCNEGOCIO
              WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

        $std = $this->connection->prepare($sql);
        $std->execute($parametro);
        return $std->fetchAll();
    }

    public function getBusinessPartnerStandardFinancialIndices($params)
    {
        $sql = "SELECT FCT_INDICESPADRPARC.NRINDICESPADRPARC,
                       FCT_INDICESPADRPARC.NRPARCNEGOCIO,
                       FCT_INDICESPADRPARC.CDTPINDICE,
                       FCT_INDICESPADRPARC.IDPERVALOR,
                       FCT_INDICESPADRPARC.CDINDICE,
                       INDICE.NMINDICE,
                       INDICE.SGINDICE,
                       FCT_INDICESPADRPARC.NRPERCENTINDICE,
                       FCT_INDICESPADRPARC.IDATIVO,
                       FCT_INDICESPADRPARC.NRORG,
                       FCT_INDICESPADRPARC.DTINCLUSAO,
                       FCT_INDICESPADRPARC.NRORGINCLUSAO,
                       FCT_INDICESPADRPARC.CDOPERINCLUSAO,
                       FCT_INDICESPADRPARC.DTULTATU,
                       FCT_INDICESPADRPARC.NRORGULTATU,
                       FCT_INDICESPADRPARC.CDOPERULTATU
                  FROM FCT_INDICESPADRPARC
                  JOIN INDICE
                    ON INDICE.CDTPINDICE = FCT_INDICESPADRPARC.CDTPINDICE
                   AND INDICE.IDPERVALOR = FCT_INDICESPADRPARC.IDPERVALOR
                   AND INDICE.CDINDICE   = FCT_INDICESPADRPARC.CDINDICE
                   AND INDICE.NRORG      = FCT_INDICESPADRPARC.NRORG
                 WHERE FCT_INDICESPADRPARC.NRPARCNEGOCIO = :NRPARCNEGOCIO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function inserirIndiceFinanceiroPadraoParceiro(array $params)
    {
        $sql = "INSERT INTO FCT_INDICESPADRPARC (
                    NRINDICESPADRPARC,  NRPARCNEGOCIO,  CDTPINDICE,
                    IDPERVALOR,         CDINDICE,       NRPERCENTINDICE,
                    NRORG,              IDATIVO,        DTINCLUSAO,
                    NRORGINCLUSAO,      CDOPERINCLUSAO
                )
                VALUES (
                    :NRINDICESPADRPARC,  :NRPARCNEGOCIO,  :CDTPINDICE,
                    :IDPERVALOR,         :CDINDICE,       :NRPERCENTINDICE,
                    :NRORG,              :IDATIVO,        SYSDATE,
                    :NRORGINCLUSAO,      :CDOPERINCLUSAO
                )";

        $this->connection->executeStatement($sql, $params);
    }

    public function atualizarIndiceFinanceiroPadraoParceiro(array $params)
    {
        $sql = "UPDATE FCT_INDICESPADRPARC
                   SET CDTPINDICE      = :CDTPINDICE,
                       IDPERVALOR      = :IDPERVALOR,
                       CDINDICE        = :CDINDICE,
                       NRPERCENTINDICE = :NRPERCENTINDICE,
                       DTULTATU        = SYSDATE,
                       CDOPERULTATU    = :CDOPERULTATU,
                       NRORGULTATU     = :NRORGULTATU
                 WHERE NRINDICESPADRPARC = :NRINDICESPADRPARC
                   AND NRORG             = :NRORG";

        $this->connection->executeStatement($sql, $params);
    }

    public function excluirIndiceFinanceiroPadraoParceiro($nrindicespadrparc, $nrorg)
    {
        $sql = "DELETE FROM FCT_INDICESPADRPARC
                 WHERE NRINDICESPADRPARC IN ($nrindicespadrparc)
                   AND NRORG             = :NRORG";

        $this->connection->executeStatement($sql, array("NRORG" => $nrorg));
    }

    public function getSomaPercentualIndicesParceiro(array $params)
    {
        $sql = "SELECT NVL(SUM(NRPERCENTINDICE), 0) AS NRPERCENTINDICE 
                  FROM FCT_INDICESPADRPARC
                 WHERE NRPARCNEGOCIO      = :NRPARCNEGOCIO
                   AND NRINDICESPADRPARC <> NVL(:NRINDICESPADRPARC, -1)";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function validarIndiceDuplicadoParceiro(array $params)
    {
        $sql = "SELECT COUNT(*) AS EXISTE
                  FROM FCT_INDICESPADRPARC
                 WHERE NRPARCNEGOCIO      = :NRPARCNEGOCIO
                   AND CDTPINDICE         = :CDTPINDICE
                   AND IDPERVALOR         = :IDPERVALOR
                   AND CDINDICE           = :CDINDICE
                   AND NRINDICESPADRPARC <> NVL(:NRINDICESPADRPARC, -1)";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function inserirBairro(array $params)
    {
        $sql = "INSERT INTO BAIRRO (
                    CDPAIS,       SGESTADO,        CDMUNICIPIO,
                    CDBAIRRO,     NMBAIRRO,        NRORG,
                    DTINCLUSAO,   NRORGINCLUSAO,   CDOPERINCLUSAO
                )
                VALUES (
                    :CDPAIS,       :SGESTADO,        :CDMUNICIPIO,
                    :CDBAIRRO,     :NMBAIRRO,        :NRORG,
                    SYSDATE,       :NRORGINCLUSAO,   :CDOPERINCLUSAO
                )";

        $this->connection->executeStatement($sql, $params);
    }

    public function getQtdClienteParceiro(array $params)
    {
        $sql = "SELECT NRPARCNEGOCIO, NRINSJURCLIE
                  FROM CLIENTE
                 WHERE NRINSJURCLIE = :NRINSCRICAOPARC";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function getQtdFornecedorParceiro(array $params)
    {
        $sql = "SELECT NRPARCNEGOCIO, NRINSJURFORN
                  FROM FORNECEDOR
                 WHERE NRINSJURFORN = :NRINSCRICAOPARC";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function getQtdVendedorParceiro(array $params)
    {
        $sql = "SELECT NRPARCNEGOCIO, NRINSJURVEN
                  FROM VENDEDOR
                 WHERE NRINSJURVEN = :NRINSCRICAOPARC";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function getQtdProspectParceiro(array $params)
    {
        $sql = "SELECT NRPARCNEGOCIO, NRINSJURPROS
                  FROM PROSPECT
                 WHERE NRINSJURPROS = :NRINSCRICAOPARC";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function insertENDECLIE(array $params)
    {
        $sql = "INSERT INTO ENDECLIE (
                    NRENDERECOPARC,     CDCLIENTE,      IDTPENDECLIE,
                    CDPAIS,             SGESTADO,       CDMUNICIPIO,
                    DSENDECLIE,         CDBAIRRO,       DSCOMPENDCLI,
                    NMBAIRCLIE,         NRCEPCLIE,      IDATIVO,
                    NRORG,              DTINCLUSAO,     CDOPERINCLUSAO,
                    NRORGINCLUSAO
                )
                VALUES (
                    :NRENDERECOPARC,     :CDCLIENTE,      :IDTPENDECLIE,
                    :CDPAIS,             :SGESTADO,       :CDMUNICIPIO,
                    :DSENDECLIE,         :CDBAIRRO,       :DSCOMPENDCLI,
                    :NMBAIRCLIE,         :NRCEPCLIE,      :IDATIVO,
                    :NRORG,              SYSDATE,         :CDOPERINCLUSAO,
                    :NRORGINCLUSAO
                )";

        $this->connection->executeStatement($sql, $params);
    }

    public function updateENDECLIE(array $params)
    {
        $sql = "UPDATE ENDECLIE
                   SET IDTPENDECLIE = :IDTPENDECLIE,
                       CDPAIS       = :CDPAIS,
                       SGESTADO     = :SGESTADO,
                       CDMUNICIPIO  = :CDMUNICIPIO,
                       DSENDECLIE   = :DSENDECLIE,
                       CDBAIRRO     = :CDBAIRRO,
                       DSCOMPENDCLI = :DSCOMPENDCLI,
                       NMBAIRCLIE   = :NMBAIRCLIE,
                       NRCEPCLIE    = :NRCEPCLIE,
                       IDATIVO      = :IDATIVO,
                       DTULTATU     = SYSDATE,
                       CDOPERULTATU = :CDOPERULTATU,
                       NRORGULTATU  = :NRORGULTATU,
                       NRENDERECOPARC = :NRENDERECOPARC
                  WHERE CDCLIENTE = :CDCLIENTE
                  AND IDTPENDECLIE = :IDTPENDECLIE_OLD";

        $this->connection->executeStatement($sql, $params);
    }

    public function deleteENDECLIE(array $params)
    {
        $sql = "DELETE FROM ENDECLIE
                 WHERE NRENDERECOPARC = :NRENDERECOPARC";

        $this->connection->executeStatement($sql, $params);
    }

    public function insertENDEFORN(array $params)
    {
        $sql = "INSERT INTO ENDEFORN (
                    NRENDERECOPARC,   CDFORNECED,      IDTPENDEFORN,
                    CDPAIS,           SGESTADO,        CDMUNICIPIO,
                    DSENDEFORN,       DSCOMPENDFOR,    NMBAIRFORN,
                    NRCEPFORN,        IDATIVO,         NRORG,
                    DTINCLUSAO,       CDOPERINCLUSAO,  NRORGINCLUSAO
                )
                VALUES (
                    :NRENDERECOPARC,   :CDFORNECED,      :IDTPENDEFORN,
                    :CDPAIS,           :SGESTADO,        :CDMUNICIPIO,
                    :DSENDEFORN,       :DSCOMPENDFOR,    :NMBAIRFORN,
                    :NRCEPFORN,        :IDATIVO,         :NRORG,
                    SYSDATE,           :CDOPERINCLUSAO,  :NRORGINCLUSAO
                )";

        $this->connection->executeStatement($sql, $params);
    }

    public function updateENDEFORN(array $params)
    {
        $sql = "UPDATE ENDEFORN
                   SET IDTPENDEFORN = :IDTPENDEFORN,
                       CDPAIS       = :CDPAIS,
                       SGESTADO     = :SGESTADO,
                       CDMUNICIPIO  = :CDMUNICIPIO,
                       DSENDEFORN   = :DSENDEFORN,
                       DSCOMPENDFOR = :DSCOMPENDFOR,
                       NMBAIRFORN   = :NMBAIRFORN,
                       NRCEPFORN    = :NRCEPFORN,
                       IDATIVO      = :IDATIVO,
                       DTULTATU     = SYSDATE,
                       CDOPERULTATU = :CDOPERULTATU,
                       NRORGULTATU  = :NRORGULTATU
                       WHERE CDFORNECED = :CDFORNECED
                  AND IDTPENDEFORN = :IDTPENDEFORN_OLD";

        $this->connection->executeStatement($sql, $params);
    }

    public function deleteENDEFORN(array $params)
    {
        $sql = "DELETE FROM ENDEFORN
                 WHERE NRENDERECOPARC = :NRENDERECOPARC";

        $this->connection->executeStatement($sql, $params);
    }

    public function insertENDEVENDE(array $params)
    {
        $sql = "INSERT INTO ENDEVENDE (
                    NRENDERECOPARC,   CDVENDEDOR,      IDTPENDEVEN,
                    CDPAIS,           SGESTADO,        CDMUNICIPIO,
                    DSENDEVEN,        CDBAIRRO,        NMBAIRVEN,
                    NRCEPVEN,         IDATIVO,         NRORG,
                    DTINCLUSAO,       CDOPERINCLUSAO,  NRORGINCLUSAO
                )
                VALUES (
                    :NRENDERECOPARC,   :CDVENDEDOR,      :IDTPENDEVEN,
                    :CDPAIS,           :SGESTADO,        :CDMUNICIPIO,
                    :DSENDEVEN,        :CDBAIRRO,        :NMBAIRVEN,
                    :NRCEPVEN,         :IDATIVO,         :NRORG,
                    SYSDATE,           :CDOPERINCLUSAO,  :NRORGINCLUSAO
                )";

        $this->connection->executeStatement($sql, $params);
    }

    public function updateENDEVENDE(array $params)
    {
        $sql = "UPDATE ENDEVENDE
                   SET IDTPENDEVEN  = :IDTPENDEVEN,
                       CDPAIS       = :CDPAIS,
                       SGESTADO     = :SGESTADO,
                       CDMUNICIPIO  = :CDMUNICIPIO,
                       DSENDEVEN    = :DSENDEVEN,
                       CDBAIRRO     = :CDBAIRRO,
                       NMBAIRVEN    = :NMBAIRVEN,
                       NRCEPVEN     = :NRCEPVEN,
                       IDATIVO      = :IDATIVO,
                       DTULTATU     = SYSDATE,
                       CDOPERULTATU = :CDOPERULTATU,
                       NRORGULTATU  = :NRORGULTATU
                       WHERE CDVENDEDOR = :CDVENDEDOR
                  AND IDTPENDEVEN = :IDTPENDEVEN_OLD";

        $this->connection->executeStatement($sql, $params);
    }

    public function deleteENDEVENDE(array $params)
    {
        $sql = "DELETE FROM ENDEVENDE
                 WHERE NRENDERECOPARC = :NRENDERECOPARC";

        $this->connection->executeStatement($sql, $params);
    }

    public function insertENDEPROSPECT(array $params)
    {
        $sql = "INSERT INTO ENDEPROSPECT (
                    NRENDERECOPARC,   CDPROSPECT,       IDTPENDEPROS,
                    CDPAIS,           SGESTADO,         CDMUNICIPIO,
                    DSENDEPROS,       CDBAIRRO,         NMBAIRPROS,
                    NRCEPPROS,        NRIMOVELENDERECO, IDATIVO,
                    NRORG,            DTINCLUSAO,       CDOPERINCLUSAO,
                    NRORGINCLUSAO
                )
                VALUES (
                    :NRENDERECOPARC,   :CDPROSPECT,       :IDTPENDEPROS,
                    :CDPAIS,           :SGESTADO,         :CDMUNICIPIO,
                    :DSENDEPROS,       :CDBAIRRO,         :NMBAIRPROS,
                    :NRCEPPROS,        :NRIMOVELENDERECO, :IDATIVO,
                    :NRORG,            SYSDATE,           :CDOPERINCLUSAO,
                    :NRORGINCLUSAO
                )";

        $this->connection->executeStatement($sql, $params);
    }

    public function updateENDEPROSPECT(array $params)
    {
        $sql = "UPDATE ENDEPROSPECT
                   SET IDTPENDEPROS     = :IDTPENDEPROS,
                       CDPAIS           = :CDPAIS,
                       SGESTADO         = :SGESTADO,
                       CDMUNICIPIO      = :CDMUNICIPIO,
                       DSENDEPROS       = :DSENDEPROS,
                       CDBAIRRO         = :CDBAIRRO,
                       NMBAIRPROS       = :NMBAIRPROS,
                       NRCEPPROS        = :NRCEPPROS,
                       NRIMOVELENDERECO = :NRIMOVELENDERECO,
                       IDATIVO          = :IDATIVO,
                       DTULTATU         = SYSDATE,
                       CDOPERULTATU     = :CDOPERULTATU,
                       NRORGULTATU      = :NRORGULTATU
                       WHERE CDPROSPECT = :CDPROSPECT
                  AND IDTPENDEPROS = :IDTPENDEPROS_OLD";

        $this->connection->executeStatement($sql, $params);
    }

    public function deleteENDEPROSPECT(array $params)
    {
        $sql = "DELETE FROM ENDEPROSPECT
                 WHERE NRENDERECOPARC = :NRENDERECOPARC";

        $this->connection->executeStatement($sql, $params);
    }

    public function getCodigoClienteParceiro(array $params)
    {
        $sql = "SELECT CDCLIENTE
                  FROM CLIENTE
                 WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function getCodigoFornecedorParceiro(array $params)
    {
        $sql = "SELECT CDFORNECED
                  FROM FORNECEDOR
                 WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function getCodigoVendedorParceiro(array $params)
    {
        $sql = "SELECT CDVENDEDOR
                  FROM VENDEDOR
                 WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function getCodigoProspectParceiro(array $params)
    {
        $sql = "SELECT CDPROSPECT
                  FROM PROSPECT
                 WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function getQtdEnderecoClienteParceiro(array $params)
    {
        $sql = "SELECT COUNT(*) AS QTD
                  FROM ENDECLIE
                 WHERE CDCLIENTE = :CDCLIENTE
                   AND IDTPENDECLIE = :IDTPENDECLIE";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function getQtdEnderecoFornecedorParceiro(array $params)
    {
        $sql = "SELECT COUNT(*) AS QTD
                  FROM ENDEFORN
                 WHERE CDFORNECED = :CDFORNECED
                   AND IDTPENDEFORN = :IDTPENDEFORN";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function getQtdEnderecoVendedorParceiro(array $params)
    {
        $sql = "SELECT COUNT(*) AS QTD
                  FROM ENDEVENDE
                 WHERE CDVENDEDOR = :CDVENDEDOR
                   AND IDTPENDEVEN = :IDTPENDEVEN";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function getQtdEnderecoProspectParceiro(array $params)
    {
        $sql = "SELECT COUNT(*) AS QTD
                  FROM ENDEPROSPECT
                 WHERE CDPROSPECT = :CDPROSPECT
                   AND IDTPENDEPROS = :IDTPENDEPROS";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function getParceiroPorInscricao(array $params)
    {
        $sql = "SELECT NRPARCNEGOCIO,
                       NMPRINCIPALPARC,
                       NMSECUNDARIPARC,
                       IDATIVO
                  FROM PARCNEGOCIO
                 WHERE NRINSCRICAOPARC = :NRINSCRICAOPARC
                   AND NRPARCNEGOCIO <> NVL(:NRPARCNEGOCIO, -1)";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function getClienteSemParceiroPorInscricao(array $params)
    {
        $sql = "SELECT CDCLIENTE,
                       NMRAZSOCCLIE,
                       NMFANTCLIE,
                       IDATIVO,
                       IDCLIEATIV,
                       NRPARCNEGOCIO
                  FROM CLIENTE
                 WHERE NRINSJURCLIE = :NRINSJURCLIE
                   AND NRPARCNEGOCIO IS NULL";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function getImportTipoParceiro()
    {

        $sql = "SELECT CDTIPOPARCEIRO, NMTIPOPARCEIRO
                FROM TIPOPARCEIRO
                WHERE IDATIVO = 'S'
                AND  CDTIPOPARCEIRO  
                NOT IN ('ESTRUTURA', 'TRANSPORTADORA', 'FUNCIONARIO', 'INTERLOCUTOR', 'CANDIDATO', 'OPERADOR', 'PESSOA', 'REVENDA')
                ORDER BY NMTIPOPARCEIRO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getNomeCliente()
    {
        $sql = "SELECT CDCLIENTE AS CDTIPOPARC,
                NMFANTCLIE AS NOMETIPOPARC
                FROM CLIENTE
                WHERE IDATIVO = 'S' AND 
                NRPARCNEGOCIO IS NULL";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getNomeFornecedor()
    {
        $sql = "SELECT CDFORNECED AS CDTIPOPARC,
                NMFANTFORN AS NOMETIPOPARC
                FROM FORNECEDOR
                WHERE IDATIVO = 'S'AND 
                NRPARCNEGOCIO IS NULL";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getNomeProspect()
    {
        $sql = "SELECT CDPROSPECT AS CDTIPOPARC,
                NMFANTPROS AS NOMETIPOPARC
                FROM PROSPECT
                WHERE IDATIVO = 'S' AND
                NRPARCNEGOCIO IS NULL";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getNomeVendedor()
    {
        $sql = "SELECT CDVENDEDOR AS CDTIPOPARC,
                NMFANVEN AS NOMETIPOPARC
                FROM VENDEDOR
                WHERE IDATIVO = 'S' AND
                NRPARCNEGOCIO IS NULL";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getCliente(array $params)
    {
        $sql = "SELECT NRORG,
                CDSEGMER,
                NMRAZSOCCLIE,
                NMFANTCLIE,
                IDTPIJURCLIE,
                NRINSJURCLIE,
                DTNASCCLIE,
                NRORGINCLUSAO,
                CDOPERINCLUSAO,
                NRINSESTCLIE
                FROM CLIENTE 
                WHERE CDCLIENTE = :CDCLIENTE";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function insertImportBusinessPartner(array $params)
    {
            
        $sql = "INSERT INTO PARCNEGOCIO (NRPARCNEGOCIO, NRORG, CDSEGMER, NMPRINCIPALPARC, NMSECUNDARIPARC,
                DTNASCIFUNDPARC, NRINSCRICAOPARC, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, 
                NRINSCESTADUAL, CDTIPOPARCPRINCIPAL, CDTIPOINSCRICAO, IDINSTITUICAO)
                VALUES (:NRPARCNEGOCIO,
                        :NRORG,
                        :CDSEGMER,
                        :NMPRINCIPALPARC,
                        :NMSECUNDARIPARC,
                        :DTNASCIFUNDPARC,
                        :NRINSCRICAOPARC,
                        :IDATIVO,
                        SYSDATE,
                        :NRORGINCLUSAO,
                        :CDOPERINCLUSAO,
                        :NRINSCESTADUAL,
                        :CDTIPOPARCPRINCIPAL,
                        :CDTIPOINSCRICAO,
                        :IDINSTITUICAO)";

        $this->connection->executeStatement($sql, $params);
    }

    public function getEndeCli(array $params)
    {
        $sql = "SELECT IDTPENDECLIE,
                IDATIVO,
                NRORG,
                NRORGINCLUSAO,
                CDOPERINCLUSAO,
                NRORGULTATU,
                CDOPERULTATU,
                CDPAIS,
                SGESTADO,
                CDMUNICIPIO,
                DSENDECLIE,
                NMBAIRCLIE,
                DSCOMPENDCLI,
                NRCEPCLIE
                FROM ENDECLIE
                WHERE CDCLIENTE = :CDCLIENTE";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function insertAddressImportBusinessPartner(array $params)
    {
            
        $sql = "INSERT INTO ENDERECOPARC (NRENDERECOPARC, NRPARCNEGOCIO, CDTIPOENDERECO, IDATIVO, NRORG, 
                DTINCLUSAO, DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU, CDPAIS, 
                SGESTADO, CDMUNICIPIO, DSENDERECO, NMBAIRROENDERECO, DSCOMPLEENDERECO, NRCEPENDERECO)
                VALUES (:NRENDERECOPARC,
                        :NRPARCNEGOCIO,
                        :CDTIPOENDERECO,
                        :IDATIVO,
                        :NRORG,
                        SYSDATE,
                        SYSDATE,
                        :NRORGINCLUSAO,
                        :CDOPERINCLUSAO,
                        :NRORGULTATU,
                        :CDOPERULTATU,
                        :CDPAIS,
                        :SGESTADO,
                        :CDMUNICIPIO,
                        :DSENDERECO,
                        :NMBAIRROENDERECO,
                        :DSCOMPLEENDERECO,
                        :NRCEPENDERECO)";

        $this->connection->executeStatement($sql, $params);
    }

    public function getProspect(array $params)
    {
        $sql = "SELECT NRORG,
                CDSEGMER,
                NMRAZSOCPROS,
                NMFANTPROS,
                IDTPIJURPROS,
                NRINSJURPROS,
                DTNASCPROS,
                NRORGINCLUSAO,
                CDOPERINCLUSAO,
                NRINSESTPROS
                FROM PROSPECT 
                WHERE CDPROSPECT = :CDPROSPECT";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function getEndePros(array $params)
    {
        $sql = "SELECT IDTPENDEPROS,
                IDATIVO,
                NRORG,
                NRORGINCLUSAO,
                CDOPERINCLUSAO,
                NRORGULTATU,
                CDOPERULTATU,
                CDPAIS,
                SGESTADO,
                CDMUNICIPIO,
                DSENDEPROS,
                NMBAIRPROS,
                DSCOMPENDPRO,
                NRCEPPROS
                FROM ENDEPROSPECT
                WHERE CDPROSPECT = :CDPROSPECT";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function getFornecedor(array $params)
    {
        $sql = "SELECT NRORG,
                CDSEGMER,
                NMRAZSOCFORN,
                NMFANTFORN,
                IDTPIJURFORN,
                NRINSJURFORN,
                NRORGINCLUSAO,
                CDOPERINCLUSAO
                FROM FORNECEDOR 
                WHERE CDFORNECED = :CDFORNECED";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function validaParceria(array $params)
    {
        $sql = "SELECT COUNT(*) AS QTD
                FROM PARCERIA
                WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO
                AND CDTIPOPARCEIRO = :CDTIPOPARCEIRO
                AND NRORG = :NRORG";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function insertParceria(array $params)
    {
            
        $sql = "INSERT INTO PARCERIA 
                (NRPARCERIA,     NRPARCNEGOCIO,      CDTIPOPARCEIRO,      NRORG)
                VALUES  
                (:NRPARCERIA,    :NRPARCNEGOCIO,     :CDTIPOPARCEIRO,     :NRORG)";

        $this->connection->executeStatement($sql, $params);
    }

    public function getEndeForn(array $params)
    {
        $sql = "SELECT IDTPENDEFORN,
                IDATIVO,
                NRORG,
                NRORGINCLUSAO,
                CDOPERINCLUSAO,
                NRORGULTATU,
                CDOPERULTATU,
                CDPAIS,
                SGESTADO,
                CDMUNICIPIO,
                DSENDEFORN,
                NMBAIRFORN,
                DSCOMPENDFOR,
                NRCEPFORN,
                NRTELEFORN,
                NRRAMALFORN,
                NRTELRESIFOR,
                NRCELULARFOR,
                NRFAXFORN,
                DSEMAILFORN
                FROM ENDEFORN
                WHERE CDFORNECED = :CDFORNECED";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function validaComunicaParc(array $params)
    {
        $sql = "SELECT NRCOMUNICAPARC
                FROM COMUNICAPARC
                WHERE NRENDERECOPARC = :NRENDERECOPARC
                AND NRPARCNEGOCIO = :NRPARCNEGOCIO
                AND NRORG = :NRORG
                AND CDFORMACOMU = :CDFORMACOMU";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function deleteComunicaParc(array $params)
    {
        $sql = "DELETE FROM COMUNICAPARC
                WHERE NRCOMUNICAPARC = :NRCOMUNICAPARC";

        $this->connection->executeStatement($sql, $params);
    }

    public function insertComunicaParc(array $params)
    {
        $sql = "INSERT INTO COMUNICAPARC 
                (
                NRCOMUNICAPARC,      NRPARCNEGOCIO,      CDFORMACOMU,           NRENDERECOPARC,
                CDCOMUNICAPARC,      IDATIVO,            CDCOMPLECOMUPARC,      NRORG,   
                DTINCLUSAO,          DTULTATU,           NRORGINCLUSAO,         CDOPERINCLUSAO,     
                NRORGULTATU,         CDOPERULTATU
                )
                VALUES  
                (
                :NRCOMUNICAPARC,     :NRPARCNEGOCIO,      :CDFORMACOMU,           :NRENDERECOPARC,
                :CDCOMUNICAPARC,     :IDATIVO,            :CDCOMPLECOMUPARC,      :NRORG,   
                SYSDATE,             SYSDATE,             :NRORGINCLUSAO,         :CDOPERINCLUSAO,     
                :NRORGULTATU,        :CDOPERULTATU
                )";

        $this->connection->executeStatement($sql, $params);
    }

    public function getVendedor(array $params)
    {
        $sql = "SELECT NRORG,
                NMRAZSOCVEN,
                NMFANVEN,
                IDTPIJURVEN,
                NRINSJURVEN,
                DTNASCVEN,
                NRORGINCLUSAO,
                CDOPERINCLUSAO
                FROM VENDEDOR 
                WHERE CDVENDEDOR = :CDVENDEDOR";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function getEndeVen(array $params)
    {
        $sql = "SELECT IDTPENDEVEN,
                IDATIVO,
                NRORG,
                NRORGINCLUSAO,
                CDOPERINCLUSAO,
                NRORGULTATU,
                CDOPERULTATU,
                CDPAIS,
                SGESTADO,
                CDMUNICIPIO,
                DSENDEVEN,
                NMBAIRVEN,
                NRCEPVEN
                FROM ENDEVENDE
                WHERE CDVENDEDOR = :CDVENDEDOR";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }
    
}