<?php

namespace PAR\Service;

use PAR\Factory\PartnerClassificationFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class PartnerClassificationService
{

    protected $connection;
    protected $PartnerClassificationFactory;
    protected $environment;
    protected $newCode;

    public function __construct(PartnerClassificationFactory $PartnerClassificationFactory, Environment $environment, NewCode $newCode, EntityManager $entityManager)
    {
        $this->PartnerClassificationFactory = $PartnerClassificationFactory;
        $this->connection                   = $entityManager->getConnection();
        $this->environment                  = $environment;
        $this->newCode                      = $newCode;
    }

    public function getPartnerClassification()
    {
        return $this->PartnerClassificationFactory->getPartnerClassification();
    }

    public function insertPartnerClassification($parametros)
    {
        $cdoperador = $this->environment->getCdOperador();
        $NRORG = $this->environment->getNrOrg();
        $this->connection->beginTransaction();
        try {
            foreach ($parametros as $chave => $classification) {
                if ($classification["NRTPCLASSIFICAPARC"] == 0) {
                    $NRTPCLASSIFICAPARC = $this->newCode->getCodeByTableName("TIPOCLASSIFICAPARC", $NRORG, 1, 10, true);
                    $dataParam = array(
                        "NRTPCLASSIFICAPARC" => $NRTPCLASSIFICAPARC,
                        "NMCLASSIFICAPARC"   => $classification["NMCLASSIFICAPARC"],
                        "NRORG"              => $NRORG,
                        "NRORGINCLUSAO"      => $NRORG,
                        "CDOPERINCLUSAO"     => $cdoperador,
                    );
                    $this->PartnerClassificationFactory->insertPartnerClassification($dataParam);
                } else {
                    $dataParam = array(
                        "NRTPCLASSIFICAPARC" => $classification["NRTPCLASSIFICAPARC"],
                        "NMCLASSIFICAPARC"  => $classification["NMCLASSIFICAPARC"],
                        "CDOPERULTATU"      => $cdoperador,
                        "NRORGULTATU"       => $NRORG,
                    );
                    $this->PartnerClassificationFactory->updatePartnerClassification($dataParam);
                }
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deletePartnerClassification($parametros)
    {
        $this->connection->beginTransaction();
        try {
            foreach ($parametros as $chave => $classification) {
                $dataParam = array("NRTPCLASSIFICAPARC" => $classification["NRTPCLASSIFICAPARC"],);
                $this->PartnerClassificationFactory->deletePartnerClassification($dataParam);
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
}
