import {
    Http, IDictionary, IEventParam, Metadata,
} from '@zeedhi/core';
import {
    AlertService, Date as ZdDate, DialogService, Form, LoadingService, Modal, ModalService, Select,
    SelectMultiple, Tabs, Text, TextInput, Button, Image, FileInput,
} from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';
import { ValidaInscricao } from '@/util/ValidaInscricao';

export class BusinessPartnerController {
    private addNewPartner!: Modal;

    private importarTpParc!: Modal;

    public gridVisivel: boolean = true;

    public currentRow: any = {};

    get formVisivel() {
        return !this.gridVisivel;
    }

    public NAMEOFCORPORATE: string = '';

    private IDPESSOAFISICA: any;

    private IDINSTITUICAO: any;

    public openPreview({ row }: any) {
        this.gridVisivel = false;
        this.currentRow = row;
        this.mountInformationOfBusinessPartners();
        this.controlarAbaIndicesFinanceiros();
        this.changeBusinessPartnerTabs();
    }

    public clickButtonToExpand({ component }: any) {
        const form = Metadata.getInstance<Form>(component.name.split('_')[1]);
        form.isVisible = !form.isVisible;

        component.iconName = (component.iconName === 'mdi-chevron-down') ? 'mdi-chevron-right' : 'mdi-chevron-down';
    }

    public voltarGrid() {
        this.gridVisivel = true;
    }

    public alertMessage(message: string, type: string) {
        AlertService.show({
            name: 'basic-alert',
            text: message,
            top: true,
            left: false,
            timeout: 3000,
            color: type,
        });
    }

    public dialogMessage(message: string) {
        DialogService.show({
            name: 'warning-dialog',
            type: 'warning',
            title: 'Erro!',
            text: message,
        });
    }

    public changeInscricaoFrame({ component }: IEventParam<TextInput>) {
        const tipoInscricao = Metadata.getInstance<Select>('formEditRegistrationType').value;
        this.changeInscricao(component, tipoInscricao);
    }

    public changeInscricaoModal({ component }: IEventParam<TextInput>) {
        const tipoInscricao = Metadata.getInstance<Select>('formNewPartner-registrationType').value;
        this.changeInscricao(component, tipoInscricao);
    }

    public changeInscricao(component: any, tipoInscricao: any) {
        if (tipoInscricao === 'LIVRE') {
            if (component.value.search(/[a-zA-Z]/) === -1) {
                component.value = component.value.padStart(20, '0');
            }
        } else if (tipoInscricao === 'CODIGO') {
            component.value = component.value.padStart(5, '0');
        } else if (tipoInscricao === 'CPF') {
            const cpfValido = ValidaInscricao.validateCPF(component.value);
            if (!cpfValido) {
                Utilities.showAlertMessage('Número de Inscrição Inválido', 'error');
                component.value = null;
            }
        } else if (tipoInscricao === 'CNPJ') {
            const cnpjValido = ValidaInscricao.validateCNPJ(component.value);
            if (!cnpjValido) {
                Utilities.showAlertMessage('Número de Inscrição Inválido', 'error');
                component.value = null;
            }
        }
    }

    public changeTipoInscricaoFrame() {
        Metadata.getInstance<TextInput>('formRegistrationNumber').value = null;
    }

    public changeTipoInscricaoModal() {
        Metadata.getInstance<TextInput>('formNewPartner-Nregistration').value = null;
    }

    public validateRegistration(nameSelect: string, nameText: string, valueRegistration: string) {
        const selectTypeRegistration = Metadata.getInstance<Select>(nameSelect);
        const textInputNumberRegistration = Metadata.getInstance<TextInput>(nameText);

        if (valueRegistration) {
            const validations = this.validateRegistrationFormat(valueRegistration);

            if (validations.cod === 'CPF') {
                this.IDPESSOAFISICA = 'S';
                this.IDINSTITUICAO = 'N';
            } else {
                this.IDPESSOAFISICA = 'N';
                this.IDINSTITUICAO = 'S';

                if (validations.cod !== 'CNPJ') textInputNumberRegistration.value = validations.value;
            }

            if (validations.valid === false) {
                selectTypeRegistration.value = Metadata.getInstance<Select>(nameSelect).value;
                textInputNumberRegistration.value = null;
                this.alertMessage('Número de Inscrição Inválido', 'error');
            }
        } else {
            selectTypeRegistration.value = Metadata.getInstance<Select>(nameSelect).value;
            textInputNumberRegistration.value = null;
        }
    }

    public fill(value: string, length: number, toRight: boolean = false, filler: any = '') {
        let fillerVar = filler;
        if (value) {
            let valor = value.toString();

            if (fillerVar) {
                [fillerVar] = filler.toString();
            } else fillerVar = '0';

            if (toRight) while (valor.length + fillerVar.length <= length) valor += fillerVar;
            else while (valor.length + fillerVar.length <= length) valor = fillerVar + valor;
        }
        return value;
    }

    public validateRegistrationFormat(registration: string, force: boolean = false) {
        const TypeRegistration: IDictionary = {
            parameter: '',
            value: '',
            valid: null,
            cod: null,
            name: '',
        };

        if (registration === undefined || registration === null || registration === '') {
            return TypeRegistration;
        }
        const registrationVar = registration.toString().replace(/[\D]+/g, '');
        let forceVar = force;

        if (registrationVar.length <= 5) {
            TypeRegistration.cod = 'CODIGO';
            TypeRegistration.name = 'Còdigo genérico';
            TypeRegistration.valid = true;
            TypeRegistration.value = this.fill(registrationVar, 5);
        } else {
            if (registrationVar.length === 11) {
                TypeRegistration.cod = 'CPF';
                TypeRegistration.name = 'Pessoa física';
                TypeRegistration.valid = ValidaInscricao.validateCPF(registrationVar);
                TypeRegistration.value = `${registrationVar.substr(0, 3)}.${registrationVar.substr(3, 3)}.${registrationVar.substr(6, 3)}-${registrationVar.substr(9, 2)}`;
            } else if (registrationVar.length === 14) {
                TypeRegistration.cod = 'CNPJ';
                TypeRegistration.name = 'Pessoa jurídica';
                TypeRegistration.valid = ValidaInscricao.validateCNPJ(registrationVar);
                TypeRegistration.value = `${registrationVar.substr(0, 2)}.${registrationVar.substr(2, 3)}.${registrationVar.substr(5, 3)}/${registrationVar.substr(8, 4)}-${registrationVar.substr(12, 2)}`;
            } else forceVar = true;
            if (forceVar && TypeRegistration.valid !== true) {
                TypeRegistration.cod = 'LIVRE';
                TypeRegistration.name = 'Inscrição Internacional';

                if (registrationVar.length <= 20) {
                    TypeRegistration.valid = true;
                    TypeRegistration.value = this.fill(registrationVar, 20);
                } else {
                    TypeRegistration.valid = false;
                    TypeRegistration.value = registrationVar.substr(0, 20);
                }
            }
        }

        TypeRegistration.parameter = registrationVar;
        return TypeRegistration;
    }

    // ---------------------- Add Business Partner Modal Functions -----------

    public async openModalNewPartner() {
        this.addNewPartner = await ModalService.createFromJson('sources/BusinessPartner/Modal/modal-partner-registration', true);
        this.addNewPartner.show();
    }

    public closeModalNewPartner() {
        this.addNewPartner.hide();
        this.addNewPartner?.destroy();
    }

    /* Função que chama a API dos correios e seta os valores nos campos de endereço
     Faz uma validação buscando o código do bairro no banco de dados pois não é retornado pela API */
    public async validateCEP() {
        const CEP = Metadata.getInstance<TextInput>('BPForm-CEP').value.replace('-', '');

        if (CEP) {
            LoadingService.show();
            (this.searchCep(CEP) as any).then(async (response: IDictionary) => {
                const addressFound = response.data.dataset.ENDERECO;

                if (addressFound) {
                    Metadata.getInstance<Select>('BPForm-country').setValue('');
                    Metadata.getInstance<Select>('BPForm-state').setValue('');
                    Metadata.getInstance<Select>('BPForm-city').setValue('');

                    Metadata.getInstance<TextInput>('BPForm-address').value = (addressFound.DSENDERECO) ? addressFound.DSENDERECO : '';
                    await Metadata.getInstance<Select>('BPForm-country').setValue((addressFound.CDPAIS) ? addressFound.CDPAIS : '');
                    await Metadata.getInstance<Select>('BPForm-state').setValue((addressFound.SGESTADO) ? addressFound.SGESTADO : '');
                    await Metadata.getInstance<Select>('BPForm-city').setValue((addressFound.CDMUNICIPIO) ? addressFound.CDMUNICIPIO : '');
                    if (addressFound.CDBAIRRO === '') {
                        Http.post('/findCodeDistrict', {
                            NMBAIRRO: addressFound.NMBAIRRO,
                            SGESTADO: addressFound.SGESTADO,
                            CDPAIS: addressFound.CDPAIS,
                            CDMUNICIPIO: addressFound.CDMUNICIPIO,
                        }).then(() => {
                            response.data.dataset.codeFound.forEach((codeFound: IDictionary) => {
                                Metadata.getInstance<Select>('BPForm-district').setValue((codeFound.CDBAIRRO) ? codeFound.CDBAIRRO : '');
                            });
                        });
                    }
                }
            }).catch((error: any) => {
                if (error.data) this.alertMessage(error.data.error, 'error');
                else this.alertMessage('Erro ao realizar a busca.', 'error');
                // Metadata.getInstance<TextInput>('BPForm-CEP').value = '';
                Metadata.getInstance<TextInput>('BPForm-address').value = '';
                Metadata.getInstance<Select>('BPForm-country').value = '';
                Metadata.getInstance<Select>('BPForm-state').value = '';
                Metadata.getInstance<Select>('BPForm-city').value = '';
                Metadata.getInstance<Select>('BPForm-district').value = '';
            }).finally(() => {
                LoadingService.hide();
            });
        }
        // await this.changeStateToEnabled();
    }

    // Faz uma busca pelo CEP através da API do Correio, e retorna o endereço em formato de promise.
    public searchCep(cepValue: number) {
        if (String(cepValue).length === 8) {
            return Http.post('/lib_findAddress', {
                requestType: 'Row',
                row: { CEP: cepValue },
            });
        }
        return 0;
    }

    /* Função que habilita o campo de Estado caso o campo de País esteja com um valor
     e filtra os estados a partir do País selecionado */
    public async changeStateToEnabled() {
        const selectCountry = Metadata.getInstance<Select>('BPForm-country');
        const selectState = Metadata.getInstance<Select>('BPForm-state');

        if (!selectCountry.value) {
            selectState.disabled = true;
            selectState.value = '';
        } else {
            selectState.disabled = false;
            selectState.datasource.setFilter({
                CDPAIS: selectCountry.value,
            });
        }
        await this.changeCityToEnabled();
    }

    /* Função que habilita o campo de Município caso o campo de Estado esteja com um valor
     e filtra os municípios a partir do Estado selecionado */
    public async changeCityToEnabled() {
        const selectCountry = Metadata.getInstance<Select>('BPForm-country');
        const selectState = Metadata.getInstance<Select>('BPForm-state');
        const selectCity = Metadata.getInstance<Select>('BPForm-city');

        if (!selectState.value) {
            selectCity.disabled = true;
            selectCity.value = '';
        } else {
            selectCity.disabled = false;
            selectCity.datasource.setFilter({
                CDPAIS: selectCountry.value,
                SGESTADO: selectState.value,
            });
        }
        await this.changeDistrictToEnabled();
    }

    /* Função que habilita o campo de Bairro caso o campo de Município esteja com um valor
     e filtra os bairros a partir do Município selecionado */
    public async changeDistrictToEnabled() {
        const selectCountry = Metadata.getInstance<Select>('BPForm-country');
        const selectState = Metadata.getInstance<Select>('BPForm-state');
        const selectCity = Metadata.getInstance<Select>('BPForm-city');
        const selectDistrict = Metadata.getInstance<Select>('BPForm-district');

        if (!selectCity.value) {
            selectDistrict.disabled = true;
            selectDistrict.value = '';
        } else {
            selectDistrict.disabled = false;
            selectDistrict.datasource.setFilter({
                CDPAIS: selectCountry.value,
                SGESTADO: selectState.value,
                CDMUNICIPIO: selectCity.value,
            });
        }
    }

    public validateRegistrationOfModalAddNewPartner() {
        const registrationTpe = Metadata.getInstance<Select>('formNewPartner-registrationType').name;
        const registration = Metadata.getInstance<TextInput>('formNewPartner-Nregistration');
        this.validateRegistration(registrationTpe, registration.name, registration.value);
    }

    public insertNewBusinessPartner() {
        const FormBP = Metadata.getInstance<Form>('formNewPartner').validate();
        const FormAddress = Metadata.getInstance<Form>('BPForm').validate();
        const DISTRICT = Metadata.getInstance<Select>('BPForm-district').value;
        const grid = Metadata.getInstance<TekGrid>('gridBusinessPartner');
        const typeRegistration = Metadata.getInstance<Select>('formNewPartner-registrationType').value;

        if (FormBP && FormAddress) {
            LoadingService.show();
            Http.post('/insertNewBusinessPartner', {
                CDTIPOINSCRICAO: typeRegistration,
                NRINSCRICAOPARC: Metadata.getInstance<TextInput>('formNewPartner-Nregistration').value,
                IDATIVO: Metadata.getInstance<Select>('formNewPartner-active').value,
                CDTIPOPARCPRINCIPAL: Metadata.getInstance<Select>('formNewPartner-mainType').value,
                NRTPCLASSIFICAPARC: Metadata.getInstance<Select>('formNewPartner-partnerClassification').value,
                CDTIPOPARCEIRO: Metadata.getInstance<Select>('formNewPartner-typeOfPartner').value,
                NMPRINCIPALPARC: Metadata.getInstance<TextInput>('formNewPartner-corporateName').value,
                NMSECUNDARIPARC: Metadata.getInstance<TextInput>('formNewPartner-shortName').value,
                CDOPERRESPONSAVEL: Metadata.getInstance<Select>('formNewPartner-operator').value,
                DTNASCIFUNDPARC: Metadata.getInstance<ZdDate>('formAdditionalData-initialDate').value,
                CDSEGMER: Metadata.getInstance<Select>('formAdditionalData-markedSegment').value,
                CDATIVCLI: Metadata.getInstance<Select>('formAdditionalData-branchOfActivity').value,
                NRSEQTPATIVCLI: Metadata.getInstance<Select>('formAdditionalData-typeOfActivity').value,
                IDPESSOAFISICA: (typeRegistration === 'CPF') ? 'S' : 'N',
                IDINSTITUICAO: (typeRegistration === 'CNPJ') ? 'S' : 'N',
                CDTIPOENDERECO: Metadata.getInstance<Select>('BPForm-typeAddress').value,
                NRCEPENDERECO: Metadata.getInstance<TextInput>('BPForm-CEP').value,
                DSENDERECO: Metadata.getInstance<TextInput>('BPForm-address').value,
                NRIMOVELENDERECO: Metadata.getInstance<TextInput>('BPForm-number').value,
                DSCOMPLEENDERECO: Metadata.getInstance<TextInput>('BPForm-additionalAddress').value,
                DSREFERENCIAENDE: Metadata.getInstance<TextInput>('BPForm-reference').value,
                CDPAIS: Metadata.getInstance<Select>('BPForm-country').value,
                SGESTADO: Metadata.getInstance<Select>('BPForm-state').value,
                CDMUNICIPIO: Metadata.getInstance<Select>('BPForm-city').value,
                CDBAIRRO: (DISTRICT === null) ? null : DISTRICT.CDBAIRRO,
                CDOPERADOR: localStorage.getItem('CDOPERADOR'),
                NMBAIRROENDERECO: (DISTRICT === null) ? null : DISTRICT.NMBAIRRO,
                CDINSCESTA: Metadata.getInstance<TextInput>('formAdditionalData-INSCESTAD').value,
                CDINSCMUNI: Metadata.getInstance<TextInput>('formAdditionalData-INSCMUNI').value,
                CDIDIOM: Metadata.getInstance<Select>('formConfRegional-CDIDIOM').value,
                NRMOEDA: Metadata.getInstance<Select>('formConfRegional-NRMOEDA').value,
            })
                .then(() => {
                    this.alertMessage('Parceiro de Negócio adicionado com sucesso!', 'success');
                    this.closeModalNewPartner();
                    grid.datasource.get();
                })
                .catch((error: any) => {
                    Utilities.showErrorMessage(error);
                })
                .finally(() => {
                    LoadingService.hide();
                });
        } else {
            this.alertMessage('Por favor, preencha todos os campos obrigatórios(*)!', 'error');
        }
    }

    // ---------------------- Função para iniciar com o Filtro aberto ------------------
    public openFilter({ component }: any) {
        const filterButton = Metadata.getInstance<Button>(`${component.name}_filterButton`);
        filterButton.click({} as Event, {} as HTMLElement);
    }
    // ---------------------- Funções da tela de visualização e edição -----------

    // Função que insere o TIPO PRINCIPAL de um parceiro de negócio, conforme selecionado no campo de TIPO DE PARCEIRO.
    public putValueOnSelectOfMainType({ component }: any) {
        const select = (component.name === 'formNewPartner-typeOfPartner') ? Metadata.getInstance<Select>('formNewPartner-mainType') : Metadata.getInstance<Select>('formEditMainType');

        if (!component.value || component.value.length === 0) {
            select.setValue(null);
        } else if (!component.value.includes(select.value)) {
            select.setValue(component.value[0]);
        }
    }

    public getMaskInscricaoFrame() {
        const valTipIncFrame = Metadata.getInstance<Select>('formEditRegistrationType').value;
        if (valTipIncFrame === 'CPF') {
            return '###.###.###-##';
        }
        if (valTipIncFrame === 'CNPJ') {
            return '##.###.###/####-##';
        }
        if (valTipIncFrame === 'CODIGO') {
            return '#####';
        }
        if (valTipIncFrame === 'LIVRE') {
            return 'NNNNNNNNNNNNNNNNNNNN';
        }
        return '';
    }

    public getMaskInscricaoModal() {
        const valTipIncModal = Metadata.getInstance<Select>('formNewPartner-registrationType').value;
        if (valTipIncModal === 'CPF') {
            return '###.###.###-##';
        }
        if (valTipIncModal === 'CNPJ') {
            return '##.###.###/####-##';
        }
        if (valTipIncModal === 'CODIGO') {
            return '#####';
        }
        if (valTipIncModal === 'LIVRE') {
            return 'NNNNNNNNNNNNNNNNNNNN';
        }
        return '';
    }

    public mountInformationOfBusinessPartners() {
        const { NRPARCNEGOCIO } = this.currentRow;

        LoadingService.show();
        Http.post('/getSpecificBusinessPartner', { NRPARCNEGOCIO }).then((response: IDictionary) => {
            LoadingService.hide();
            response.data.dataset.partnerFound.forEach((data: IDictionary) => {
                Metadata.getInstance<Text>('nameOfCorporate').text = data.NMPRINCIPALPARC;
                Metadata.getInstance<Select>('formEditRegistrationType').setValue(data.CDTIPOINSCRICAO);
                setTimeout(() => {
                    Metadata.getInstance<TextInput>('formRegistrationNumber').value = data.NRINSCRICAOPARC;
                }, 100);
                Metadata.getInstance<Select>('formEditActive').setValue(data.IDATIVO);
                Metadata.getInstance<Select>('formEditMainType').setValue(data.CDTIPOPARCPRINCIPAL);
                Metadata.getInstance<Select>('formEditPartnerClassification').setValue(data.NRTPCLASSIFICAPARC);
                Metadata.getInstance<Select>('formEditOperator').setValue(data.CDOPERRESPONSAVEL);
                Metadata.getInstance<TextInput>('formEditCorporateName').value = data.NMPRINCIPALPARC;
                Metadata.getInstance<TextInput>('formEditShortName').value = data.NMSECUNDARIPARC;
                Metadata.getInstance<ZdDate>('formEditFoundation').value = data.DTNASCIFUNDPARC;
                Metadata.getInstance<Select>('formEditMarkedSegment').setValue(data.CDSEGMER);
                Metadata.getInstance<Select>('formEditBranchOfActivity').setValue(data.CDATIVCLI);
                Metadata.getInstance<Select>('formEditTypeOfActivity').setValue(data.NRSEQTPATIVCLI);
                Metadata.getInstance<TextInput>('formIncludeIn').value = data.DTINCLUSAO;
                Metadata.getInstance<TextInput>('formIncludeBy').value = data.NMOPERINCLUSAO;
                Metadata.getInstance<TextInput>('formChangedIn').value = data.DTULTATU;
                Metadata.getInstance<TextInput>('formChangedBy').value = data.NMOPERULTATU;
                Metadata.getInstance<TextInput>('formEditAdditionalData-INSCESTAD').value = data.CDINSCESTA;
                Metadata.getInstance<TextInput>('formEditAdditionalData-INSCMUNI').value = data.CDINSCMUNI;
                Metadata.getInstance<Select>('formEditConfRegional-CDIDIOM').value = data.CDIDIOM;
                Metadata.getInstance<Select>('formEditConfRegional-NRMOEDA').value = data.NRMOEDA;
                this.NAMEOFCORPORATE = data.NMPRINCIPALPARC;
                if (data.TIPODEPARCEIRO) {
                    Metadata.getInstance<SelectMultiple>('formEditTypeOfPartner').setValue(data.TIPODEPARCEIRO.split(', '));
                } else {
                    data.TIPODEPARCEIRO = data.CDTIPOPARCPRINCIPAL;
                    Metadata.getInstance<SelectMultiple>('formEditTypeOfPartner').setValue(data.TIPODEPARCEIRO.split(', '));
                }
            });
        }).catch((error: any) => {
            LoadingService.hide();
            Utilities.showErrorMessage(error);
        });
    }

    public saveSpecificBusinessPartner() {
        const { NRPARCNEGOCIO } = this.currentRow;
        const formBP = Metadata.getInstance<Form>('formEditBusinessPartner');
        const typeRegistration = Metadata.getInstance<Select>('formEditRegistrationType').value;
        const rownrinscricao = Metadata.getInstance<TextInput>('formRegistrationNumber').value;
        let editouInscricao = true;
        if (this.currentRow.NRINSCRICAOPARC === rownrinscricao) {
            editouInscricao = false;
        }
        if (formBP.validate()) {
            LoadingService.show();
            Http.post('updateSpecificBusinessPartner', {
                NRPARCNEGOCIO,
                editouInscricao,
                IDATIVO: Metadata.getInstance<Select>('formEditActive').value,
                CDSEGMER: Metadata.getInstance<Select>('formEditMarkedSegment').value,
                NMPRINCIPALPARC: Metadata.getInstance<TextInput>('formEditCorporateName').value,
                NMSECUNDARIPARC: Metadata.getInstance<TextInput>('formEditShortName').value,
                DTNASCIFUNDPARC: Metadata.getInstance<ZdDate>('formEditFoundation').value,
                NRINSCRICAOPARC: Metadata.getInstance<TextInput>('formRegistrationNumber').value,
                CDOPERADOR: localStorage.getItem('CDOPERADOR'),
                CDTIPOPARCPRINCIPAL: Metadata.getInstance<Select>('formEditMainType').value,
                CDTIPOINSCRICAO: typeRegistration,
                IDPESSOAFISICA: (typeRegistration === 'CPF') ? 'S' : 'N',
                IDINSTITUICAO: (typeRegistration === 'CNPJ') ? 'S' : 'N',
                CDATIVCLI: Metadata.getInstance<Select>('formEditBranchOfActivity').value,
                NRSEQTPATIVCLI: Metadata.getInstance<Select>('formEditTypeOfActivity').value,
                CDOPERRESPONSAVEL: Metadata.getInstance<Select>('formEditOperator').value,
                NRTPCLASSIFICAPARC: Metadata.getInstance<Select>('formEditPartnerClassification').value,
                CDINSCESTA: Metadata.getInstance<TextInput>('formEditAdditionalData-INSCESTAD').value,
                CDINSCMUNI: Metadata.getInstance<TextInput>('formEditAdditionalData-INSCMUNI').value,
                CDTIPOPARCEIRO: Metadata.getInstance<Select>('formEditTypeOfPartner').value,
                CDIDIOM: Metadata.getInstance<Select>('formEditConfRegional-CDIDIOM').value,
                NRMOEDA: Metadata.getInstance<Select>('formEditConfRegional-NRMOEDA').value,
            })
                .then(() => {
                    this.alertMessage('Parceiro de Negócio alterado com sucesso!', 'success');
                    const gridParceiro = Metadata.getInstance<TekGrid>('gridBusinessPartner');
                    gridParceiro.datasource.get();
                })
                .catch((error: any) => {
                    Utilities.showErrorMessage(error);
                })
                .finally(() => {
                    LoadingService.hide();
                });
        } else {
            this.alertMessage('Por favor, preencha todos os campos obrigatórios(*)!', 'error');
        }
    }

    public validateRegistrationOfTabEdition() {
        const registrationTpe = Metadata.getInstance<Select>('formEditRegistrationType').name;
        const registration = Metadata.getInstance<TextInput>('formRegistrationNumber');
        this.validateRegistration(registrationTpe, registration.name, registration.value);
    }

    public controlarAbaIndicesFinanceiros() {
        const tipoPrincipal = this.currentRow.CDTIPOPARCPRINCIPAL;
        const tabs = Metadata.getInstance<Tabs>('tabsInformation');
        let tabIndiceFinanceiro = 0;
        tabs.tabs.forEach((t, index) => {
            if (t.name === 'tab_standardFinancialIndices') {
                tabIndiceFinanceiro = index;
            }
        });

        tabs.tabs[tabIndiceFinanceiro].isVisible = tipoPrincipal === 'CLIENTE';
    }

    public changeBusinessPartnerTabs() {
        const tabs = Metadata.getInstance<Tabs>('tabsInformation');
        const tabAtiva = tabs.activeTab;

        if (tabs.tabs[tabAtiva].name === 'tab_address') {
            // carregar dados da aba Endereço
            this.carregarDadosAbaEndereco();
        } else if (tabs.tabs[tabAtiva].name === 'tab_communication') {
            // carregar dados da aba Comunicação
            this.carregarDadosAbaComunicacao();
        } else if (tabs.tabs[tabAtiva].name === 'tab_interlocutor') {
            // carregar dados da aba Interlocutor
            this.carregarDadosInterlocutor();
        } else if (tabs.tabs[tabAtiva].name === 'tab_bankDetails') {
            // carregar dados da aba Dados Bancários
            this.carregarDadosAbaDadosBancarios();
        } else if (tabs.tabs[tabAtiva].name === 'tab_billingParameters') {
            // carregar dados da aba Parâmetros de Faturamento
            this.carregarDadosAbaParametrosDeFaturamento();
        } else if (tabs.tabs[tabAtiva].name === 'tab_standardFinancialIndices') {
            // carregar dados da aba Índices Financeiros Padrões
            this.carregarDadosAbaIndicesFinanceiros();
        } else if (tabs.tabs[tabAtiva].name === 'tab_logo') {
            // carregar dados da aba Logotipo
            this.carregarDadosAbaLogo();
        }
    }

    public carregarDadosAbaEndereco() {
        const nrparcnegocio = this.currentRow.NRPARCNEGOCIO;
        try {
            const grid = Metadata.getInstance<TekGrid>('tekGrid-tabAddress');
            grid.datasource.setFilter({
                NRPARCNEGOCIO: nrparcnegocio,
            });
        } catch (e) {
            console.error(e);
        }
    }

    public carregarDadosAbaIndicesFinanceiros() {
        const nrparcnegocio = this.currentRow.NRPARCNEGOCIO;
        try {
            const grid = Metadata.getInstance<TekGrid>('tekgrid_tabStandardFinancialIndices');
            grid.datasource.setFilter({
                NRPARCNEGOCIO: nrparcnegocio,
            });
        } catch (e) {
            console.error(e);
        }
    }

    public carregarDadosAbaDadosBancarios() {
        const nrparcnegocio = this.currentRow.NRPARCNEGOCIO;
        try {
            const grid = Metadata.getInstance<TekGrid>('tekgrid-tabAddBankCommunication');
            grid.datasource.setFilter({
                NRPARCNEGOCIO: nrparcnegocio,
            });
        } catch (e) {
            console.error(e);
        }
    }

    public carregarDadosAbaComunicacao() {
        const nrparcnegocio = this.currentRow.NRPARCNEGOCIO;
        try {
            const grid = Metadata.getInstance<TekGrid>('tekgrid-tabCommunication');
            grid.datasource.setFilter({
                NRPARCNEGOCIO: nrparcnegocio,
            });
        } catch (e) {
            console.error(e);
        }
    }

    public carregarDadosInterlocutor() {
        const nrparcnegocio = this.currentRow.NRPARCNEGOCIO;
        try {
            const grid = Metadata.getInstance<TekGrid>('tekGrid-tabInterlocutor');
            grid.datasource.setFilter({
                NRPARCNEGOCIO: nrparcnegocio,
            });
        } catch (e) {
            console.error(e);
        }
    }

    public carregarDadosAbaParametrosDeFaturamento() {
        const nrparcnegocio = this.currentRow.NRPARCNEGOCIO;
        Http.post('/getBillingParameter', { nrparcnegocio }).then((response: IDictionary) => {
            if (response.data.dataset.parameter.length > 0) {
                response.data.dataset.parameter.forEach((data: IDictionary) => {
                    Metadata.getInstance<Text>('NRPARAMFATURA').text = data.NRPARAMFATURA;
                    Metadata.getInstance<Select>('form-filial').setValue(data.CDFILIALFATURA);
                    Metadata.getInstance<Select>('form-invoiceSeries').setValue(data.CDSERIENF);
                });
            } else {
                Metadata.getInstance<Text>('NRPARAMFATURA').text = '';
                Metadata.getInstance<Select>('form-filial').setValue(null);
                Metadata.getInstance<Select>('form-invoiceSeries').setValue(null);
            }
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        });
    }

    public carregarDadosAbaLogo() {
        const component = Metadata.getInstance<Image>('image-logotype');
        Metadata.getInstance<FileInput>('FileInputl-imagens').value = null;
        const nrparcnegocio = this.currentRow.NRPARCNEGOCIO;
        // component.isVisible = true;
        LoadingService.show();
        Http.post('/getImage', {
            NRPARCNEGOCIO: nrparcnegocio,
        }).then((response: IDictionary) => {
            const link = response.data.dataset.image[0].DSDIRLOGOMARCA;
            // const fileServerUrl = Config.env.fileServerUrl;
            const fileServerUrl = localStorage.getItem('FILESERVER_URL');
            component.src = `${fileServerUrl}/files/${link}`;
            Metadata.getInstance<Button>('deleteButtonLogotype').isVisible = false;
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public getDataNewPartner() {
        LoadingService.show();
        Utilities.getOperadorLogado().then((cdoperador) => {
            Metadata.getInstance<Select>('formNewPartner-operator').value = cdoperador;
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public async abrirModalImportar() {
        this.importarTpParc = await ModalService.createFromJson('sources/BusinessPartner/Modal/modal-importar-tipo-parceiro-negocio', true);
        this.importarTpParc.show();
    }

    public closeModalImportar() {
        this.importarTpParc.hide();
        this.importarTpParc?.destroy();
    }

    public setFilterTpParc({ component }: any) {
        const nometipoparc = Metadata.getInstance<Select>('formImportarTipoParceiroNegocio-CDTIPOPARC');
        nometipoparc.datasource.data = [];
        const cdtipoparceiro = component.value;
        try {
            nometipoparc.datasource.setFilter({
                CDTIPOPARCEIRO: cdtipoparceiro,
            });
        } catch (e) {
            console.error(e);
        }
    }

    public importarTipoParceiro() {
        const formImport = Metadata.getInstance<Form>('form-importarTipoParceiroNegocio').validate();
        const grid = Metadata.getInstance<TekGrid>('gridBusinessPartner');
        if (formImport) {
            LoadingService.show();
            Http.post('/importarTipoParceiro', {
                CDTIPOPARCEIRO: Metadata.getInstance<Select>('formImportarTipoParceiroNegocio-typeOfPartner').value,
                CDTIPOPARC: Metadata.getInstance<Select>('formImportarTipoParceiroNegocio-CDTIPOPARC').value,
            }).then(() => {
                this.alertMessage('Tipo de Parceiro importado com sucesso!', 'success');
                this.closeModalImportar();
                grid.datasource.get();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        } else {
            this.alertMessage('Por favor, preencha todos os campos obrigatórios(*)!', 'error');
        }
    }
}
